<!-- Warning: Do not manually edit this file. See notes on gluon + helm-docs at the end of this file for more information. -->
# monitoring

![Version: 69.7.3-bb.1](https://img.shields.io/badge/Version-69.7.3--bb.1-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: v0.80.1](https://img.shields.io/badge/AppVersion-v0.80.1-informational?style=flat-square) ![Maintenance Track: bb_integrated](https://img.shields.io/badge/Maintenance_Track-bb_integrated-green?style=flat-square)

kube-prometheus-stack collects Kubernetes manifests, Grafana dashboards, and Prometheus rules combined with documentation and scripts to provide easy to operate end-to-end Kubernetes cluster monitoring with Prometheus using the Prometheus Operator.

## Upstream References

- <https://github.com/prometheus-operator/kube-prometheus>
- <https://github.com/prometheus-community/helm-charts>
- <https://github.com/prometheus-operator/kube-prometheus>

## Upstream Release Notes

- [Find our upstream chart's CHANGELOG here](https://github.com/prometheus-community/helm-charts/blob/main/charts/kube-prometheus-stack/README.md#upgrading-chart)
- [and our upstream application release notes here](https://github.com/prometheus-operator/kube-prometheus/blob/main/CHANGELOG.md)

## Learn More

- [Application Overview](docs/overview.md)
- [Other Documentation](docs/)

## Pre-Requisites

- Kubernetes Cluster deployed
- Kubernetes config installed in `~/.kube/config`
- Helm installed

Kubernetes: `>=1.19.0-0`

Install Helm

https://helm.sh/docs/intro/install/

## Deployment

- Clone down the repository
- cd into directory

```bash
helm install monitoring chart/
```

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| domain | string | `"dev.bigbang.mil"` |  |
| flux.enabled | bool | `false` |  |
| flux.namespace | string | `"flux-system"` |  |
| networkPolicies.enabled | bool | `false` |  |
| networkPolicies.controlPlaneCidr | string | `"0.0.0.0/0"` |  |
| networkPolicies.ingressLabels.app | string | `"istio-ingressgateway"` |  |
| networkPolicies.ingressLabels.istio | string | `"ingressgateway"` |  |
| networkPolicies.alertmanager | object | `{"enableEgress":false}` | This toggle enables a NetworkPolicy that will allow external egress providing the ability to send alerts to external resources like MM/Slack/etc. |
| networkPolicies.additionalPolicies | list | `[]` |  |
| openshift | bool | `false` |  |
| bbtests.enabled | bool | `false` |  |
| bbtests.cypress.artifacts | bool | `true` |  |
| bbtests.cypress.envs.cypress_prometheus_url | string | `"http://monitoring-kube-prometheus-prometheus:9090"` |  |
| bbtests.cypress.envs.cypress_alertmanager_url | string | `"http://monitoring-kube-prometheus-alertmanager:9093"` |  |
| istio.enabled | bool | `false` |  |
| istio.hardened.enabled | bool | `false` |  |
| istio.hardened.outboundTrafficPolicyMode | string | `"REGISTRY_ONLY"` |  |
| istio.hardened.customServiceEntries | list | `[]` |  |
| istio.hardened.customAuthorizationPolicies | list | `[]` |  |
| istio.hardened.clusterWideHardenedEnabled | bool | `false` |  |
| istio.hardened.tempo.enabled | bool | `false` |  |
| istio.hardened.tempo.namespaces[0] | string | `"tempo"` |  |
| istio.hardened.tempo.principals[0] | string | `"cluster.local/ns/tempo/sa/tempo-tempo"` |  |
| istio.hardened.loki.enabled | bool | `false` |  |
| istio.hardened.loki.namespaces[0] | string | `"logging"` |  |
| istio.hardened.loki.principals[0] | string | `"cluster.local/ns/logging/sa/logging-loki"` |  |
| istio.hardened.alloy.enabled | bool | `true` |  |
| istio.hardened.alloy.namespaces[0] | string | `"alloy"` |  |
| istio.hardened.alloy.principals[0] | string | `"cluster.local/ns/alloy/sa/alloy-alloy-metrics"` |  |
| istio.namespace | string | `"istio-system"` |  |
| istio.prometheus.enabled | bool | `true` |  |
| istio.prometheus.annotations | object | `{}` |  |
| istio.prometheus.labels | object | `{}` |  |
| istio.prometheus.gateways[0] | string | `"istio-system/main"` |  |
| istio.prometheus.hosts[0] | string | `"prometheus.{{ .Values.domain }}"` |  |
| istio.prometheus.service | string | `""` |  |
| istio.prometheus.port | string | `""` |  |
| istio.prometheus.namespace | string | `""` |  |
| istio.prometheusRule.IstioSidecarMemModerate | bool | `true` |  |
| istio.prometheusRule.IstioSidecarMemHigh | bool | `true` |  |
| istio.prometheusRule.IstioConfigValidationFailed | bool | `true` |  |
| istio.prometheusRule.Istio5XXResponseCode | bool | `true` |  |
| istio.prometheusRule.IstioSidecarEndpointError | bool | `true` |  |
| istio.prometheusRule.IstioSidecarListenerConflict | bool | `true` |  |
| istio.alertmanager.enabled | bool | `true` |  |
| istio.alertmanager.annotations | object | `{}` |  |
| istio.alertmanager.labels | object | `{}` |  |
| istio.alertmanager.gateways[0] | string | `"istio-system/main"` |  |
| istio.alertmanager.hosts[0] | string | `"alertmanager.{{ .Values.domain }}"` |  |
| istio.alertmanager.service | string | `""` |  |
| istio.alertmanager.port | string | `""` |  |
| istio.alertmanager.namespace | string | `""` |  |
| istio.injection | string | `"disabled"` |  |
| istio.mtls.mode | string | `"STRICT"` |  |
| istio.console.enabled | bool | `false` |  |
| sso.enabled | bool | `false` |  |
| sso.selector.key | string | `"protect"` |  |
| sso.selector.value | string | `"keycloak"` |  |
| tempo.enabled | bool | `false` |  |
| cleanUpgrade.enabled | bool | `false` |  |
| cleanUpgrade.image.registry | string | `"registry1.dso.mil"` |  |
| cleanUpgrade.image.repository | string | `"ironbank/big-bang/base"` |  |
| cleanUpgrade.image.tag | string | `"2.1.0"` |  |
| cleanUpgrade.image.sha | string | `""` |  |
| cleanUpgrade.resources.requests.memory | string | `"256Mi"` |  |
| cleanUpgrade.resources.requests.cpu | string | `"100m"` |  |
| cleanUpgrade.resources.limits.memory | string | `"256Mi"` |  |
| cleanUpgrade.resources.limits.cpu | string | `"100m"` |  |
| cleanUpgrade.securityContext.runAsUser | int | `1000` |  |
| cleanUpgrade.securityContext.runAsGroup | int | `1000` |  |
| cleanUpgrade.securityContext.runAsNonRoot | bool | `true` |  |
| cleanUpgrade.securityContext.allowPrivilegeEscalation | bool | `false` |  |
| cleanUpgrade.securityContext.readOnlyRootFilesystem | bool | `true` |  |
| cleanUpgrade.securityContext.capabilities.drop[0] | string | `"ALL"` |  |
| nameOverride | string | `"kube-prometheus-stack"` |  |
| namespaceOverride | string | `""` |  |
| kubeTargetVersionOverride | string | `""` |  |
| kubeVersionOverride | string | `""` |  |
| fullnameOverride | string | `""` |  |
| commonLabels | object | `{}` |  |
| crds.enabled | bool | `true` |  |
| crds.upgradeJob.enabled | bool | `false` |  |
| crds.upgradeJob.forceConflicts | bool | `false` |  |
| crds.upgradeJob.image.busybox.registry | string | `"docker.io"` |  |
| crds.upgradeJob.image.busybox.repository | string | `"busybox"` |  |
| crds.upgradeJob.image.busybox.tag | string | `"latest"` |  |
| crds.upgradeJob.image.busybox.sha | string | `""` |  |
| crds.upgradeJob.image.busybox.pullPolicy | string | `"IfNotPresent"` |  |
| crds.upgradeJob.image.kubectl.registry | string | `"registry.k8s.io"` |  |
| crds.upgradeJob.image.kubectl.repository | string | `"kubectl"` |  |
| crds.upgradeJob.image.kubectl.tag | string | `""` |  |
| crds.upgradeJob.image.kubectl.sha | string | `""` |  |
| crds.upgradeJob.image.kubectl.pullPolicy | string | `"IfNotPresent"` |  |
| crds.upgradeJob.env | object | `{}` |  |
| crds.upgradeJob.resources | object | `{}` |  |
| crds.upgradeJob.extraVolumes | list | `[]` |  |
| crds.upgradeJob.extraVolumeMounts | list | `[]` |  |
| crds.upgradeJob.nodeSelector | object | `{}` |  |
| crds.upgradeJob.affinity | object | `{}` |  |
| crds.upgradeJob.tolerations | list | `[]` |  |
| crds.upgradeJob.topologySpreadConstraints | list | `[]` |  |
| crds.upgradeJob.labels | object | `{}` |  |
| crds.upgradeJob.annotations | object | `{}` |  |
| crds.upgradeJob.podLabels | object | `{}` |  |
| crds.upgradeJob.podAnnotations | object | `{}` |  |
| crds.upgradeJob.serviceAccount.create | bool | `true` |  |
| crds.upgradeJob.serviceAccount.name | string | `""` |  |
| crds.upgradeJob.serviceAccount.annotations | object | `{}` |  |
| crds.upgradeJob.serviceAccount.labels | object | `{}` |  |
| crds.upgradeJob.serviceAccount.automountServiceAccountToken | bool | `true` |  |
| crds.upgradeJob.containerSecurityContext.allowPrivilegeEscalation | bool | `false` |  |
| crds.upgradeJob.containerSecurityContext.readOnlyRootFilesystem | bool | `true` |  |
| crds.upgradeJob.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| crds.upgradeJob.podSecurityContext.fsGroup | int | `65534` |  |
| crds.upgradeJob.podSecurityContext.runAsGroup | int | `65534` |  |
| crds.upgradeJob.podSecurityContext.runAsNonRoot | bool | `true` |  |
| crds.upgradeJob.podSecurityContext.runAsUser | int | `65534` |  |
| crds.upgradeJob.podSecurityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| customRules | object | `{}` |  |
| defaultRules.create | bool | `true` |  |
| defaultRules.rules.alertmanager | bool | `true` |  |
| defaultRules.rules.etcd | bool | `true` |  |
| defaultRules.rules.configReloaders | bool | `true` |  |
| defaultRules.rules.general | bool | `true` |  |
| defaultRules.rules.k8sContainerCpuUsageSecondsTotal | bool | `true` |  |
| defaultRules.rules.k8sContainerMemoryCache | bool | `true` |  |
| defaultRules.rules.k8sContainerMemoryRss | bool | `true` |  |
| defaultRules.rules.k8sContainerMemorySwap | bool | `true` |  |
| defaultRules.rules.k8sContainerResource | bool | `true` |  |
| defaultRules.rules.k8sContainerMemoryWorkingSetBytes | bool | `true` |  |
| defaultRules.rules.k8sPodOwner | bool | `true` |  |
| defaultRules.rules.kubeApiserverAvailability | bool | `true` |  |
| defaultRules.rules.kubeApiserverBurnrate | bool | `true` |  |
| defaultRules.rules.kubeApiserverHistogram | bool | `true` |  |
| defaultRules.rules.kubeApiserverSlos | bool | `true` |  |
| defaultRules.rules.kubeControllerManager | bool | `true` |  |
| defaultRules.rules.kubelet | bool | `true` |  |
| defaultRules.rules.kubeProxy | bool | `true` |  |
| defaultRules.rules.kubePrometheusGeneral | bool | `true` |  |
| defaultRules.rules.kubePrometheusNodeRecording | bool | `true` |  |
| defaultRules.rules.kubernetesApps | bool | `true` |  |
| defaultRules.rules.kubernetesResources | bool | `true` |  |
| defaultRules.rules.kubernetesStorage | bool | `true` |  |
| defaultRules.rules.kubernetesSystem | bool | `true` |  |
| defaultRules.rules.kubeSchedulerAlerting | bool | `true` |  |
| defaultRules.rules.kubeSchedulerRecording | bool | `true` |  |
| defaultRules.rules.kubeStateMetrics | bool | `true` |  |
| defaultRules.rules.network | bool | `true` |  |
| defaultRules.rules.node | bool | `true` |  |
| defaultRules.rules.nodeExporterAlerting | bool | `true` |  |
| defaultRules.rules.nodeExporterRecording | bool | `true` |  |
| defaultRules.rules.prometheus | bool | `true` |  |
| defaultRules.rules.prometheusOperator | bool | `true` |  |
| defaultRules.rules.windows | bool | `true` |  |
| defaultRules.appNamespacesTarget | string | `".*"` |  |
| defaultRules.keepFiringFor | string | `""` |  |
| defaultRules.labels | object | `{}` |  |
| defaultRules.annotations | object | `{}` |  |
| defaultRules.additionalRuleLabels | object | `{}` |  |
| defaultRules.additionalRuleAnnotations | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.alertmanager | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.etcd | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.configReloaders | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.general | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sContainerCpuUsageSecondsTotal | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sContainerMemoryCache | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sContainerMemoryRss | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sContainerMemorySwap | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sContainerResource | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.k8sPodOwner | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeApiserverAvailability | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeApiserverBurnrate | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeApiserverHistogram | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeApiserverSlos | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeControllerManager | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubelet | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeProxy | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubePrometheusGeneral | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubePrometheusNodeRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubernetesApps | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubernetesResources | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubernetesStorage | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubernetesSystem | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeSchedulerAlerting | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeSchedulerRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.kubeStateMetrics | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.network | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.node | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.nodeExporterAlerting | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.nodeExporterRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.prometheus | object | `{}` |  |
| defaultRules.additionalRuleGroupLabels.prometheusOperator | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.alertmanager | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.etcd | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.configReloaders | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.general | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sContainerCpuUsageSecondsTotal | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sContainerMemoryCache | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sContainerMemoryRss | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sContainerMemorySwap | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sContainerResource | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.k8sPodOwner | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeApiserverAvailability | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeApiserverBurnrate | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeApiserverHistogram | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeApiserverSlos | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeControllerManager | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubelet | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeProxy | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubePrometheusGeneral | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubePrometheusNodeRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubernetesApps | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubernetesResources | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubernetesStorage | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubernetesSystem | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeSchedulerAlerting | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeSchedulerRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.kubeStateMetrics | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.network | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.node | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.nodeExporterAlerting | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.nodeExporterRecording | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.prometheus | object | `{}` |  |
| defaultRules.additionalRuleGroupAnnotations.prometheusOperator | object | `{}` |  |
| defaultRules.additionalAggregationLabels | list | `[]` |  |
| defaultRules.runbookUrl | string | `"https://runbooks.prometheus-operator.dev/runbooks"` |  |
| defaultRules.node.fsSelector | string | `"fstype!=\"\""` |  |
| defaultRules.disabled | object | `{}` |  |
| additionalPrometheusRulesMap | object | `{}` |  |
| global.rbac.create | bool | `true` |  |
| global.rbac.createAggregateClusterRoles | bool | `false` |  |
| global.rbac.pspEnabled | bool | `false` |  |
| global.rbac.pspAnnotations | object | `{}` |  |
| global.imageRegistry | string | `""` |  |
| global.imagePullSecrets[0].name | string | `"private-registry"` |  |
| windowsMonitoring.enabled | bool | `false` |  |
| prometheus-windows-exporter.prometheus.monitor.enabled | bool | `true` |  |
| prometheus-windows-exporter.prometheus.monitor.jobLabel | string | `"jobLabel"` |  |
| prometheus-windows-exporter.releaseLabel | bool | `true` |  |
| prometheus-windows-exporter.podLabels.jobLabel | string | `"windows-exporter"` |  |
| prometheus-windows-exporter.config | string | `"collectors:\n  enabled: '[defaults],memory,container'"` |  |
| alertmanager.enabled | bool | `true` |  |
| alertmanager.annotations | object | `{}` |  |
| alertmanager.apiVersion | string | `"v2"` |  |
| alertmanager.enableFeatures | list | `[]` |  |
| alertmanager.forceDeployDashboards | bool | `false` |  |
| alertmanager.networkPolicy.enabled | bool | `false` | Enable network policy for Alertmanager |
| alertmanager.networkPolicy.policyTypes | list | `["Ingress"]` | Define policy types. If egress is enabled, both Ingress and Egress will be used Valid values are ["Ingress"] or ["Ingress", "Egress"] # |
| alertmanager.networkPolicy.gateway | object | `{"namespace":"","podLabels":{}}` | Gateway (formerly ingress controller) configuration # |
| alertmanager.networkPolicy.gateway.namespace | string | `""` | Gateway namespace # |
| alertmanager.networkPolicy.gateway.podLabels | object | `{}` | Gateway pod labels # |
| alertmanager.networkPolicy.additionalIngress | list | `[]` | Additional custom ingress rules # |
| alertmanager.networkPolicy.egress | object | `{"enabled":false,"rules":[]}` | Configure egress rules # |
| alertmanager.networkPolicy.egress.enabled | bool | `false` | Enable egress rules. When enabled, policyTypes will include Egress # |
| alertmanager.networkPolicy.egress.rules | list | `[]` | Custom egress rules # |
| alertmanager.networkPolicy.enableClusterRules | bool | `true` | Enable rules for alertmanager cluster traffic # |
| alertmanager.networkPolicy.monitoringRules | object | `{"configReloader":true,"prometheus":true}` | Configure monitoring component rules # |
| alertmanager.networkPolicy.monitoringRules.prometheus | bool | `true` | Enable ingress from Prometheus # |
| alertmanager.networkPolicy.monitoringRules.configReloader | bool | `true` | Enable ingress for config reloader metrics # |
| alertmanager.serviceAccount.create | bool | `true` |  |
| alertmanager.serviceAccount.name | string | `""` |  |
| alertmanager.serviceAccount.annotations | object | `{}` |  |
| alertmanager.serviceAccount.automountServiceAccountToken | bool | `false` |  |
| alertmanager.podDisruptionBudget.enabled | bool | `false` |  |
| alertmanager.podDisruptionBudget.minAvailable | int | `1` |  |
| alertmanager.podDisruptionBudget.maxUnavailable | string | `""` |  |
| alertmanager.config.global.resolve_timeout | string | `"5m"` |  |
| alertmanager.config.inhibit_rules[0].source_matchers[0] | string | `"severity = critical"` |  |
| alertmanager.config.inhibit_rules[0].target_matchers[0] | string | `"severity =~ warning\|info"` |  |
| alertmanager.config.inhibit_rules[0].equal[0] | string | `"namespace"` |  |
| alertmanager.config.inhibit_rules[0].equal[1] | string | `"alertname"` |  |
| alertmanager.config.inhibit_rules[1].source_matchers[0] | string | `"severity = warning"` |  |
| alertmanager.config.inhibit_rules[1].target_matchers[0] | string | `"severity = info"` |  |
| alertmanager.config.inhibit_rules[1].equal[0] | string | `"namespace"` |  |
| alertmanager.config.inhibit_rules[1].equal[1] | string | `"alertname"` |  |
| alertmanager.config.inhibit_rules[2].source_matchers[0] | string | `"alertname = InfoInhibitor"` |  |
| alertmanager.config.inhibit_rules[2].target_matchers[0] | string | `"severity = info"` |  |
| alertmanager.config.inhibit_rules[2].equal[0] | string | `"namespace"` |  |
| alertmanager.config.inhibit_rules[3].target_matchers[0] | string | `"alertname = InfoInhibitor"` |  |
| alertmanager.config.route.group_by[0] | string | `"namespace"` |  |
| alertmanager.config.route.group_wait | string | `"30s"` |  |
| alertmanager.config.route.group_interval | string | `"5m"` |  |
| alertmanager.config.route.repeat_interval | string | `"12h"` |  |
| alertmanager.config.route.receiver | string | `"null"` |  |
| alertmanager.config.route.routes[0].receiver | string | `"null"` |  |
| alertmanager.config.route.routes[0].matchers[0] | string | `"alertname = \"Watchdog\""` |  |
| alertmanager.config.receivers[0].name | string | `"null"` |  |
| alertmanager.config.templates[0] | string | `"/etc/alertmanager/config/*.tmpl"` |  |
| alertmanager.stringConfig | string | `""` |  |
| alertmanager.tplConfig | bool | `false` |  |
| alertmanager.templateFiles | object | `{}` |  |
| alertmanager.ingress.enabled | bool | `false` |  |
| alertmanager.ingress.annotations | object | `{}` |  |
| alertmanager.ingress.labels | object | `{}` |  |
| alertmanager.ingress.hosts | list | `[]` |  |
| alertmanager.ingress.paths | list | `[]` |  |
| alertmanager.ingress.tls | list | `[]` |  |
| alertmanager.route | object | `{"main":{"additionalRules":[],"annotations":{},"apiVersion":"gateway.networking.k8s.io/v1","enabled":false,"filters":[],"hostnames":[],"httpsRedirect":false,"kind":"HTTPRoute","labels":{},"matches":[{"path":{"type":"PathPrefix","value":"/"}}],"parentRefs":[]}}` | BETA: Configure the gateway routes for the chart here. More routes can be added by adding a dictionary key like the 'main' route. Be aware that this is an early beta of this feature, kube-prometheus-stack does not guarantee this works and is subject to change. Being BETA this can/will change in the future without notice, do not use unless you want to take that risk [[ref]](https://gateway-api.sigs.k8s.io/references/spec/#gateway.networking.k8s.io%2fv1alpha2) |
| alertmanager.route.main.enabled | bool | `false` | Enables or disables the route |
| alertmanager.route.main.apiVersion | string | `"gateway.networking.k8s.io/v1"` | Set the route apiVersion, e.g. gateway.networking.k8s.io/v1 or gateway.networking.k8s.io/v1alpha2 |
| alertmanager.route.main.kind | string | `"HTTPRoute"` | Set the route kind Valid options are GRPCRoute, HTTPRoute, TCPRoute, TLSRoute, UDPRoute |
| alertmanager.route.main.httpsRedirect | bool | `false` | create http route for redirect (https://gateway-api.sigs.k8s.io/guides/http-redirect-rewrite/#http-to-https-redirects) # Take care that you only enable this on the http listener of the gateway to avoid an infinite redirect. # matches, filters and additionalRules will be ignored if this is set to true. Be are |
| alertmanager.secret.annotations | object | `{}` |  |
| alertmanager.ingressPerReplica.enabled | bool | `false` |  |
| alertmanager.ingressPerReplica.annotations | object | `{}` |  |
| alertmanager.ingressPerReplica.labels | object | `{}` |  |
| alertmanager.ingressPerReplica.hostPrefix | string | `""` |  |
| alertmanager.ingressPerReplica.hostDomain | string | `""` |  |
| alertmanager.ingressPerReplica.paths | list | `[]` |  |
| alertmanager.ingressPerReplica.tlsSecretName | string | `""` |  |
| alertmanager.ingressPerReplica.tlsSecretPerReplica.enabled | bool | `false` |  |
| alertmanager.ingressPerReplica.tlsSecretPerReplica.prefix | string | `"alertmanager"` |  |
| alertmanager.service.annotations | object | `{}` |  |
| alertmanager.service.labels | object | `{}` |  |
| alertmanager.service.clusterIP | string | `""` |  |
| alertmanager.service.ipDualStack.enabled | bool | `false` |  |
| alertmanager.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| alertmanager.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| alertmanager.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| alertmanager.service.port | int | `9093` |  |
| alertmanager.service.targetPort | int | `9093` |  |
| alertmanager.service.nodePort | int | `30903` |  |
| alertmanager.service.additionalPorts | list | `[]` |  |
| alertmanager.service.externalIPs | list | `[]` |  |
| alertmanager.service.loadBalancerIP | string | `""` |  |
| alertmanager.service.loadBalancerSourceRanges | list | `[]` |  |
| alertmanager.service.externalTrafficPolicy | string | `"Cluster"` |  |
| alertmanager.service.sessionAffinity | string | `"None"` |  |
| alertmanager.service.sessionAffinityConfig.clientIP.timeoutSeconds | int | `10800` |  |
| alertmanager.service.type | string | `"ClusterIP"` |  |
| alertmanager.servicePerReplica.enabled | bool | `false` |  |
| alertmanager.servicePerReplica.annotations | object | `{}` |  |
| alertmanager.servicePerReplica.port | int | `9093` |  |
| alertmanager.servicePerReplica.targetPort | int | `9093` |  |
| alertmanager.servicePerReplica.nodePort | int | `30904` |  |
| alertmanager.servicePerReplica.loadBalancerSourceRanges | list | `[]` |  |
| alertmanager.servicePerReplica.externalTrafficPolicy | string | `"Cluster"` |  |
| alertmanager.servicePerReplica.type | string | `"ClusterIP"` |  |
| alertmanager.serviceMonitor.selfMonitor | bool | `true` |  |
| alertmanager.serviceMonitor.interval | string | `""` |  |
| alertmanager.serviceMonitor.additionalLabels | object | `{}` |  |
| alertmanager.serviceMonitor.sampleLimit | int | `0` |  |
| alertmanager.serviceMonitor.targetLimit | int | `0` |  |
| alertmanager.serviceMonitor.labelLimit | int | `0` |  |
| alertmanager.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| alertmanager.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| alertmanager.serviceMonitor.proxyUrl | string | `""` |  |
| alertmanager.serviceMonitor.scheme | string | `""` |  |
| alertmanager.serviceMonitor.enableHttp2 | bool | `true` |  |
| alertmanager.serviceMonitor.tlsConfig | object | `{}` |  |
| alertmanager.serviceMonitor.bearerTokenFile | string | `nil` |  |
| alertmanager.serviceMonitor.metricRelabelings | list | `[]` |  |
| alertmanager.serviceMonitor.relabelings | list | `[]` |  |
| alertmanager.serviceMonitor.additionalEndpoints | list | `[]` |  |
| alertmanager.alertmanagerSpec.persistentVolumeClaimRetentionPolicy | object | `{}` |  |
| alertmanager.alertmanagerSpec.podMetadata | object | `{}` |  |
| alertmanager.alertmanagerSpec.image.registry | string | `"registry1.dso.mil"` |  |
| alertmanager.alertmanagerSpec.image.repository | string | `"ironbank/opensource/prometheus/alertmanager"` |  |
| alertmanager.alertmanagerSpec.image.tag | string | `"v0.28.0"` |  |
| alertmanager.alertmanagerSpec.image.sha | string | `""` |  |
| alertmanager.alertmanagerSpec.useExistingSecret | bool | `false` |  |
| alertmanager.alertmanagerSpec.secrets | list | `[]` |  |
| alertmanager.alertmanagerSpec.automountServiceAccountToken | bool | `true` |  |
| alertmanager.alertmanagerSpec.configMaps | list | `[]` |  |
| alertmanager.alertmanagerSpec.web | object | `{}` |  |
| alertmanager.alertmanagerSpec.alertmanagerConfigSelector | object | `{}` |  |
| alertmanager.alertmanagerSpec.alertmanagerConfigNamespaceSelector | object | `{}` |  |
| alertmanager.alertmanagerSpec.alertmanagerConfiguration | object | `{}` |  |
| alertmanager.alertmanagerSpec.alertmanagerConfigMatcherStrategy | object | `{}` |  |
| alertmanager.alertmanagerSpec.logFormat | string | `"logfmt"` |  |
| alertmanager.alertmanagerSpec.logLevel | string | `"info"` |  |
| alertmanager.alertmanagerSpec.replicas | int | `1` |  |
| alertmanager.alertmanagerSpec.retention | string | `"120h"` |  |
| alertmanager.alertmanagerSpec.storage | object | `{}` |  |
| alertmanager.alertmanagerSpec.externalUrl | string | `"https://alertmanager.{{ .Values.domain }}"` |  |
| alertmanager.alertmanagerSpec.routePrefix | string | `"/"` |  |
| alertmanager.alertmanagerSpec.scheme | string | `""` |  |
| alertmanager.alertmanagerSpec.tlsConfig | object | `{}` |  |
| alertmanager.alertmanagerSpec.paused | bool | `false` |  |
| alertmanager.alertmanagerSpec.nodeSelector | object | `{}` |  |
| alertmanager.alertmanagerSpec.resources.limits.cpu | string | `"100m"` |  |
| alertmanager.alertmanagerSpec.resources.limits.memory | string | `"100Mi"` |  |
| alertmanager.alertmanagerSpec.resources.requests.cpu | string | `"100m"` |  |
| alertmanager.alertmanagerSpec.resources.requests.memory | string | `"100Mi"` |  |
| alertmanager.alertmanagerSpec.podAntiAffinity | string | `"soft"` |  |
| alertmanager.alertmanagerSpec.podAntiAffinityTopologyKey | string | `"kubernetes.io/hostname"` |  |
| alertmanager.alertmanagerSpec.affinity | object | `{}` |  |
| alertmanager.alertmanagerSpec.tolerations | list | `[]` |  |
| alertmanager.alertmanagerSpec.topologySpreadConstraints | list | `[]` |  |
| alertmanager.alertmanagerSpec.securityContext.runAsGroup | int | `2000` |  |
| alertmanager.alertmanagerSpec.securityContext.runAsNonRoot | bool | `true` |  |
| alertmanager.alertmanagerSpec.securityContext.runAsUser | int | `1000` |  |
| alertmanager.alertmanagerSpec.securityContext.fsGroup | int | `2000` |  |
| alertmanager.alertmanagerSpec.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| alertmanager.alertmanagerSpec.listenLocal | bool | `false` |  |
| alertmanager.alertmanagerSpec.containers | list | `[]` |  |
| alertmanager.alertmanagerSpec.volumes | list | `[]` |  |
| alertmanager.alertmanagerSpec.volumeMounts | list | `[]` |  |
| alertmanager.alertmanagerSpec.initContainers | list | `[]` |  |
| alertmanager.alertmanagerSpec.priorityClassName | string | `""` |  |
| alertmanager.alertmanagerSpec.additionalPeers | list | `[]` |  |
| alertmanager.alertmanagerSpec.portName | string | `"http-web"` |  |
| alertmanager.alertmanagerSpec.clusterAdvertiseAddress | bool | `false` |  |
| alertmanager.alertmanagerSpec.clusterGossipInterval | string | `""` |  |
| alertmanager.alertmanagerSpec.clusterPeerTimeout | string | `""` |  |
| alertmanager.alertmanagerSpec.clusterPushpullInterval | string | `""` |  |
| alertmanager.alertmanagerSpec.clusterLabel | string | `""` |  |
| alertmanager.alertmanagerSpec.forceEnableClusterMode | bool | `false` |  |
| alertmanager.alertmanagerSpec.minReadySeconds | int | `0` |  |
| alertmanager.alertmanagerSpec.additionalConfig | object | `{}` |  |
| alertmanager.alertmanagerSpec.additionalConfigString | string | `""` |  |
| alertmanager.extraSecret.annotations | object | `{}` |  |
| alertmanager.extraSecret.data | object | `{}` |  |
| grafana.enabled | bool | `false` |  |
| grafana.namespaceOverride | string | `""` |  |
| grafana.image.registry | string | `"registry1.dso.mil"` |  |
| grafana.image.repository | string | `"ironbank/big-bang/grafana/grafana-plugins"` |  |
| grafana.image.tag | string | `"11.5.2"` |  |
| grafana.image.pullSecrets[0] | string | `"private-registry"` |  |
| grafana.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| grafana.resources.limits.cpu | string | `"100m"` |  |
| grafana.resources.limits.memory | string | `"256Mi"` |  |
| grafana.resources.requests.cpu | string | `"100m"` |  |
| grafana.resources.requests.memory | string | `"256Mi"` |  |
| grafana.testFramework.registry | string | `"registry1.dso.mil"` |  |
| grafana.testFramework.repository | string | `"ironbank/opensource/bats/bats"` |  |
| grafana.testFramework.tag | string | `"v1.11.0"` |  |
| grafana.testFramework.pullSecrets[0] | string | `"private-registry"` |  |
| grafana.testFramework.imagePullPolicy | string | `"IfNotPresent"` |  |
| grafana.testFramework.securityContext.capabilites.drop[0] | string | `"ALL"` |  |
| grafana.forceDeployDatasources | bool | `false` |  |
| grafana.forceDeployDashboards | bool | `false` |  |
| grafana.defaultDashboardsEnabled | bool | `true` |  |
| grafana.defaultDashboardsTimezone | string | `"utc"` |  |
| grafana.defaultDashboardsEditable | bool | `true` |  |
| grafana.adminUser | string | `"admin"` |  |
| grafana.adminPassword | string | `"prom-operator"` |  |
| grafana."grafana.ini"."auth.generic_oauth".enabled | bool | `false` |  |
| grafana."grafana.ini"."auth.generic_oauth".client_id | string | `"grafana"` |  |
| grafana."grafana.ini"."auth.generic_oauth".client_secret | string | `"secret"` |  |
| grafana."grafana.ini"."auth.generic_oauth".scopes | string | `"Grafana"` |  |
| grafana."grafana.ini"."auth.generic_oauth".auth_url | string | `"https://login.dso.mil/auth/realms/baby-yoda/protocol/openid-connect/auth"` |  |
| grafana."grafana.ini"."auth.generic_oauth".token_url | string | `"https://login.dso.mil/auth/realms/baby-yoda/protocol/openid-connect/token"` |  |
| grafana."grafana.ini"."auth.generic_oauth".api_url | string | `"https://login.dso.mil/auth/realms/baby-yoda/protocol/openid-connect/userinfo"` |  |
| grafana."grafana.ini"."auth.generic_oauth".allow_sign_up | bool | `true` |  |
| grafana."grafana.ini"."auth.generic_oauth".role_attribute_path | string | `"Viewer"` |  |
| grafana."grafana.ini"."plugin.grafana-piechart-panel".path | string | `"/var/lib/bb-plugins/piechart-panel"` |  |
| grafana."grafana.ini"."plugin.grafana-polystat-panel".path | string | `"/var/lib/bb-plugins/polystat-panel"` |  |
| grafana."grafana.ini"."plugin.redis-datasource".path | string | `"/var/lib/bb-plugins/redis-datasource"` |  |
| grafana.rbac.pspEnabled | bool | `false` |  |
| grafana.ingress.enabled | bool | `false` |  |
| grafana.ingress.annotations | object | `{}` |  |
| grafana.ingress.labels | object | `{}` |  |
| grafana.ingress.hosts | list | `[]` |  |
| grafana.ingress.path | string | `"/"` |  |
| grafana.ingress.tls | list | `[]` |  |
| grafana.serviceAccount.create | bool | `true` |  |
| grafana.serviceAccount.autoMount | bool | `true` |  |
| grafana.sidecar.image.registry | string | `"registry1.dso.mil"` |  |
| grafana.sidecar.image.repository | string | `"ironbank/kiwigrid/k8s-sidecar"` |  |
| grafana.sidecar.image.tag | string | `"1.30.0"` |  |
| grafana.sidecar.resources.limits.cpu | string | `"100m"` |  |
| grafana.sidecar.resources.limits.memory | string | `"100Mi"` |  |
| grafana.sidecar.resources.requests.cpu | string | `"100m"` |  |
| grafana.sidecar.resources.requests.memory | string | `"100Mi"` |  |
| grafana.sidecar.securityContext.capabilities.drop[0] | string | `"ALL"` |  |
| grafana.sidecar.dashboards.enabled | bool | `true` |  |
| grafana.sidecar.dashboards.label | string | `"grafana_dashboard"` |  |
| grafana.sidecar.dashboards.labelValue | string | `"1"` |  |
| grafana.sidecar.dashboards.searchNamespace | string | `"ALL"` |  |
| grafana.sidecar.dashboards.enableNewTablePanelSyntax | bool | `false` |  |
| grafana.sidecar.dashboards.annotations | object | `{}` |  |
| grafana.sidecar.dashboards.multicluster.global.enabled | bool | `false` |  |
| grafana.sidecar.dashboards.multicluster.etcd.enabled | bool | `false` |  |
| grafana.sidecar.dashboards.provider.allowUiUpdates | bool | `false` |  |
| grafana.sidecar.datasources.enabled | bool | `true` |  |
| grafana.sidecar.datasources.defaultDatasourceEnabled | bool | `true` |  |
| grafana.sidecar.datasources.isDefaultDatasource | bool | `true` |  |
| grafana.sidecar.datasources.name | string | `"Prometheus"` |  |
| grafana.sidecar.datasources.uid | string | `"prometheus"` |  |
| grafana.sidecar.datasources.annotations | object | `{}` |  |
| grafana.sidecar.datasources.httpMethod | string | `"POST"` |  |
| grafana.sidecar.datasources.createPrometheusReplicasDatasources | bool | `false` |  |
| grafana.sidecar.datasources.label | string | `"grafana_datasource"` |  |
| grafana.sidecar.datasources.labelValue | string | `"1"` |  |
| grafana.sidecar.datasources.exemplarTraceIdDestinations | object | `{}` |  |
| grafana.sidecar.datasources.alertmanager.enabled | bool | `true` |  |
| grafana.sidecar.datasources.alertmanager.name | string | `"Alertmanager"` |  |
| grafana.sidecar.datasources.alertmanager.uid | string | `"alertmanager"` |  |
| grafana.sidecar.datasources.alertmanager.handleGrafanaManagedAlerts | bool | `false` |  |
| grafana.sidecar.datasources.alertmanager.implementation | string | `"prometheus"` |  |
| grafana.dashboardProviders | object | `{}` |  |
| grafana.downloadDashboardsImage.registry | string | `"registry1.dso.mil"` |  |
| grafana.downloadDashboardsImage.repository | string | `"ironbank/big-bang/base"` |  |
| grafana.downloadDashboardsImage.tag | string | `"2.1.0"` |  |
| grafana.downloadDashboards.resources.limits.cpu | string | `"20m"` |  |
| grafana.downloadDashboards.resources.limits.memory | string | `"20Mi"` |  |
| grafana.downloadDashboards.resources.requests.cpu | string | `"20m"` |  |
| grafana.downloadDashboards.resources.requests.memory | string | `"20Mi"` |  |
| grafana.dashboards | object | `{}` |  |
| grafana.extraConfigmapMounts | list | `[]` |  |
| grafana.extraSecretMounts | list | `[]` |  |
| grafana.deleteDatasources | list | `[]` |  |
| grafana.additionalDataSources | list | `[]` |  |
| grafana.prune | bool | `false` |  |
| grafana.service.portName | string | `"http-web"` |  |
| grafana.service.ipFamilies | list | `[]` |  |
| grafana.service.ipFamilyPolicy | string | `""` |  |
| grafana.serviceMonitor.enabled | bool | `true` |  |
| grafana.serviceMonitor.path | string | `"/metrics"` |  |
| grafana.serviceMonitor.labels | object | `{}` |  |
| grafana.serviceMonitor.interval | string | `""` |  |
| grafana.serviceMonitor.scheme | string | `"http"` |  |
| grafana.serviceMonitor.tlsConfig | object | `{}` |  |
| grafana.serviceMonitor.scrapeTimeout | string | `"30s"` |  |
| grafana.serviceMonitor.relabelings | list | `[]` |  |
| grafana.persistence.type | string | `"pvc"` |  |
| grafana.persistence.enabled | bool | `false` |  |
| grafana.persistence.accessModes[0] | string | `"ReadWriteOnce"` |  |
| grafana.persistence.size | string | `"10Gi"` |  |
| grafana.initChownData.enabled | bool | `false` |  |
| grafana.initChownData.image.registry | string | `"registry1.dso.mil"` |  |
| grafana.initChownData.image.repository | string | `"ironbank/redhat/ubi/ubi9-minimal"` |  |
| grafana.initChownData.image.tag | string | `"9.5"` |  |
| grafana.initChownData.image.sha | string | `""` |  |
| grafana.initChownData.image.pullPolicy | string | `"IfNotPresent"` |  |
| grafana.initChownData.resources.limits.cpu | string | `"100m"` |  |
| grafana.initChownData.resources.limits.memory | string | `"128Mi"` |  |
| grafana.initChownData.resources.requests.cpu | string | `"100m"` |  |
| grafana.initChownData.resources.requests.memory | string | `"128Mi"` |  |
| kiali.enabled | bool | `false` |  |
| kubernetesServiceMonitors.enabled | bool | `true` |  |
| kubeApiServer.enabled | bool | `true` |  |
| kubeApiServer.tlsConfig.serverName | string | `"kubernetes"` |  |
| kubeApiServer.tlsConfig.insecureSkipVerify | bool | `false` |  |
| kubeApiServer.serviceMonitor.interval | string | `""` |  |
| kubeApiServer.serviceMonitor.sampleLimit | int | `0` |  |
| kubeApiServer.serviceMonitor.targetLimit | int | `0` |  |
| kubeApiServer.serviceMonitor.labelLimit | int | `0` |  |
| kubeApiServer.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeApiServer.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeApiServer.serviceMonitor.proxyUrl | string | `""` |  |
| kubeApiServer.serviceMonitor.jobLabel | string | `"component"` |  |
| kubeApiServer.serviceMonitor.selector.matchLabels.component | string | `"apiserver"` |  |
| kubeApiServer.serviceMonitor.selector.matchLabels.provider | string | `"kubernetes"` |  |
| kubeApiServer.serviceMonitor.metricRelabelings[0].action | string | `"drop"` |  |
| kubeApiServer.serviceMonitor.metricRelabelings[0].regex | string | `"(etcd_request\|apiserver_request_slo\|apiserver_request_sli\|apiserver_request)_duration_seconds_bucket;(0\\.15\|0\\.2\|0\\.3\|0\\.35\|0\\.4\|0\\.45\|0\\.6\|0\\.7\|0\\.8\|0\\.9\|1\\.25\|1\\.5\|1\\.75\|2\|3\|3\\.5\|4\|4\\.5\|6\|7\|8\|9\|15\|20\|30\|40\|45\|50)(\\.0)?"` |  |
| kubeApiServer.serviceMonitor.metricRelabelings[0].sourceLabels[0] | string | `"__name__"` |  |
| kubeApiServer.serviceMonitor.metricRelabelings[0].sourceLabels[1] | string | `"le"` |  |
| kubeApiServer.serviceMonitor.relabelings | list | `[]` |  |
| kubeApiServer.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeApiServer.serviceMonitor.targetLabels | list | `[]` |  |
| kubelet.enabled | bool | `true` |  |
| kubelet.namespace | string | `"kube-system"` |  |
| kubelet.serviceMonitor.kubelet | bool | `true` |  |
| kubelet.serviceMonitor.attachMetadata.node | bool | `false` |  |
| kubelet.serviceMonitor.interval | string | `""` |  |
| kubelet.serviceMonitor.honorLabels | bool | `true` |  |
| kubelet.serviceMonitor.honorTimestamps | bool | `true` |  |
| kubelet.serviceMonitor.trackTimestampsStaleness | bool | `true` |  |
| kubelet.serviceMonitor.sampleLimit | int | `0` |  |
| kubelet.serviceMonitor.targetLimit | int | `0` |  |
| kubelet.serviceMonitor.labelLimit | int | `0` |  |
| kubelet.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubelet.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubelet.serviceMonitor.proxyUrl | string | `""` |  |
| kubelet.serviceMonitor.https | bool | `true` |  |
| kubelet.serviceMonitor.insecureSkipVerify | bool | `true` |  |
| kubelet.serviceMonitor.probes | bool | `true` |  |
| kubelet.serviceMonitor.resource | bool | `false` |  |
| kubelet.serviceMonitor.resourcePath | string | `"/metrics/resource/v1alpha1"` |  |
| kubelet.serviceMonitor.resourceInterval | string | `"10s"` |  |
| kubelet.serviceMonitor.cAdvisor | bool | `true` |  |
| kubelet.serviceMonitor.cAdvisorInterval | string | `"10s"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[0].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[0].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[0].regex | string | `"container_cpu_(cfs_throttled_seconds_total\|load_average_10s\|system_seconds_total\|user_seconds_total)"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[1].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[1].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[1].regex | string | `"container_fs_(io_current\|io_time_seconds_total\|io_time_weighted_seconds_total\|reads_merged_total\|sector_reads_total\|sector_writes_total\|writes_merged_total)"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[2].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[2].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[2].regex | string | `"container_memory_(mapped_file\|swap)"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[3].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[3].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[3].regex | string | `"container_(file_descriptors\|tasks_state\|threads_max)"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[4].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[4].sourceLabels[1] | string | `"scope"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[4].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[4].regex | string | `"container_memory_failures_total;hierarchy"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[5].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[5].sourceLabels[1] | string | `"interface"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[5].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[5].regex | string | `"container_network_.*;(cali\|cilium\|cni\|lxc\|nodelocaldns\|tunl).*"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[6].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[6].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[6].regex | string | `"container_spec.*"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[7].sourceLabels[0] | string | `"id"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[7].sourceLabels[1] | string | `"pod"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[7].action | string | `"drop"` |  |
| kubelet.serviceMonitor.cAdvisorMetricRelabelings[7].regex | string | `".+;"` |  |
| kubelet.serviceMonitor.probesMetricRelabelings | list | `[]` |  |
| kubelet.serviceMonitor.cAdvisorRelabelings[0].action | string | `"replace"` |  |
| kubelet.serviceMonitor.cAdvisorRelabelings[0].sourceLabels[0] | string | `"__metrics_path__"` |  |
| kubelet.serviceMonitor.cAdvisorRelabelings[0].targetLabel | string | `"metrics_path"` |  |
| kubelet.serviceMonitor.probesRelabelings[0].action | string | `"replace"` |  |
| kubelet.serviceMonitor.probesRelabelings[0].sourceLabels[0] | string | `"__metrics_path__"` |  |
| kubelet.serviceMonitor.probesRelabelings[0].targetLabel | string | `"metrics_path"` |  |
| kubelet.serviceMonitor.resourceRelabelings[0].action | string | `"replace"` |  |
| kubelet.serviceMonitor.resourceRelabelings[0].sourceLabels[0] | string | `"__metrics_path__"` |  |
| kubelet.serviceMonitor.resourceRelabelings[0].targetLabel | string | `"metrics_path"` |  |
| kubelet.serviceMonitor.metricRelabelings[0].action | string | `"drop"` |  |
| kubelet.serviceMonitor.metricRelabelings[0].sourceLabels[0] | string | `"__name__"` |  |
| kubelet.serviceMonitor.metricRelabelings[0].sourceLabels[1] | string | `"le"` |  |
| kubelet.serviceMonitor.metricRelabelings[0].regex | string | `"(csi_operations\|storage_operation_duration)_seconds_bucket;(0.25\|2.5\|15\|25\|120\|600)(\\.0)?"` |  |
| kubelet.serviceMonitor.relabelings[0].action | string | `"replace"` |  |
| kubelet.serviceMonitor.relabelings[0].sourceLabels[0] | string | `"__metrics_path__"` |  |
| kubelet.serviceMonitor.relabelings[0].targetLabel | string | `"metrics_path"` |  |
| kubelet.serviceMonitor.additionalLabels | object | `{}` |  |
| kubelet.serviceMonitor.targetLabels | list | `[]` |  |
| kubeControllerManager.enabled | bool | `true` |  |
| kubeControllerManager.endpoints | list | `[]` |  |
| kubeControllerManager.service.enabled | bool | `true` |  |
| kubeControllerManager.service.port | string | `nil` |  |
| kubeControllerManager.service.targetPort | string | `nil` |  |
| kubeControllerManager.service.ipDualStack.enabled | bool | `false` |  |
| kubeControllerManager.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| kubeControllerManager.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| kubeControllerManager.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| kubeControllerManager.serviceMonitor.enabled | bool | `true` |  |
| kubeControllerManager.serviceMonitor.interval | string | `""` |  |
| kubeControllerManager.serviceMonitor.sampleLimit | int | `0` |  |
| kubeControllerManager.serviceMonitor.targetLimit | int | `0` |  |
| kubeControllerManager.serviceMonitor.labelLimit | int | `0` |  |
| kubeControllerManager.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeControllerManager.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeControllerManager.serviceMonitor.proxyUrl | string | `""` |  |
| kubeControllerManager.serviceMonitor.port | string | `"http-metrics"` |  |
| kubeControllerManager.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| kubeControllerManager.serviceMonitor.selector | object | `{}` |  |
| kubeControllerManager.serviceMonitor.https | string | `nil` |  |
| kubeControllerManager.serviceMonitor.insecureSkipVerify | string | `nil` |  |
| kubeControllerManager.serviceMonitor.serverName | string | `nil` |  |
| kubeControllerManager.serviceMonitor.metricRelabelings | list | `[]` |  |
| kubeControllerManager.serviceMonitor.relabelings | list | `[]` |  |
| kubeControllerManager.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeControllerManager.serviceMonitor.targetLabels | list | `[]` |  |
| coreDns.enabled | bool | `true` |  |
| coreDns.service.enabled | bool | `true` |  |
| coreDns.service.port | int | `9153` |  |
| coreDns.service.targetPort | int | `9153` |  |
| coreDns.service.ipDualStack.enabled | bool | `false` |  |
| coreDns.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| coreDns.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| coreDns.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| coreDns.serviceMonitor.enabled | bool | `true` |  |
| coreDns.serviceMonitor.interval | string | `""` |  |
| coreDns.serviceMonitor.sampleLimit | int | `0` |  |
| coreDns.serviceMonitor.targetLimit | int | `0` |  |
| coreDns.serviceMonitor.labelLimit | int | `0` |  |
| coreDns.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| coreDns.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| coreDns.serviceMonitor.proxyUrl | string | `""` |  |
| coreDns.serviceMonitor.port | string | `"http-metrics"` |  |
| coreDns.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| coreDns.serviceMonitor.selector | object | `{}` |  |
| coreDns.serviceMonitor.metricRelabelings | list | `[]` |  |
| coreDns.serviceMonitor.relabelings | list | `[]` |  |
| coreDns.serviceMonitor.additionalLabels | object | `{}` |  |
| coreDns.serviceMonitor.targetLabels | list | `[]` |  |
| kubeDns.enabled | bool | `false` |  |
| kubeDns.service.dnsmasq.port | int | `10054` |  |
| kubeDns.service.dnsmasq.targetPort | int | `10054` |  |
| kubeDns.service.skydns.port | int | `10055` |  |
| kubeDns.service.skydns.targetPort | int | `10055` |  |
| kubeDns.service.ipDualStack.enabled | bool | `false` |  |
| kubeDns.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| kubeDns.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| kubeDns.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| kubeDns.serviceMonitor.interval | string | `""` |  |
| kubeDns.serviceMonitor.sampleLimit | int | `0` |  |
| kubeDns.serviceMonitor.targetLimit | int | `0` |  |
| kubeDns.serviceMonitor.labelLimit | int | `0` |  |
| kubeDns.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeDns.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeDns.serviceMonitor.proxyUrl | string | `""` |  |
| kubeDns.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| kubeDns.serviceMonitor.selector | object | `{}` |  |
| kubeDns.serviceMonitor.metricRelabelings | list | `[]` |  |
| kubeDns.serviceMonitor.relabelings | list | `[]` |  |
| kubeDns.serviceMonitor.dnsmasqMetricRelabelings | list | `[]` |  |
| kubeDns.serviceMonitor.dnsmasqRelabelings | list | `[]` |  |
| kubeDns.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeDns.serviceMonitor.targetLabels | list | `[]` |  |
| kubeEtcd.enabled | bool | `true` |  |
| kubeEtcd.endpoints | list | `[]` |  |
| kubeEtcd.service.enabled | bool | `true` |  |
| kubeEtcd.service.port | int | `2381` |  |
| kubeEtcd.service.targetPort | int | `2381` |  |
| kubeEtcd.service.ipDualStack.enabled | bool | `false` |  |
| kubeEtcd.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| kubeEtcd.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| kubeEtcd.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| kubeEtcd.serviceMonitor.enabled | bool | `true` |  |
| kubeEtcd.serviceMonitor.interval | string | `""` |  |
| kubeEtcd.serviceMonitor.sampleLimit | int | `0` |  |
| kubeEtcd.serviceMonitor.targetLimit | int | `0` |  |
| kubeEtcd.serviceMonitor.labelLimit | int | `0` |  |
| kubeEtcd.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeEtcd.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeEtcd.serviceMonitor.proxyUrl | string | `""` |  |
| kubeEtcd.serviceMonitor.scheme | string | `"http"` |  |
| kubeEtcd.serviceMonitor.insecureSkipVerify | bool | `false` |  |
| kubeEtcd.serviceMonitor.serverName | string | `""` |  |
| kubeEtcd.serviceMonitor.caFile | string | `""` |  |
| kubeEtcd.serviceMonitor.certFile | string | `""` |  |
| kubeEtcd.serviceMonitor.keyFile | string | `""` |  |
| kubeEtcd.serviceMonitor.port | string | `"http-metrics"` |  |
| kubeEtcd.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| kubeEtcd.serviceMonitor.selector | object | `{}` |  |
| kubeEtcd.serviceMonitor.metricRelabelings | list | `[]` |  |
| kubeEtcd.serviceMonitor.relabelings | list | `[]` |  |
| kubeEtcd.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeEtcd.serviceMonitor.targetLabels | list | `[]` |  |
| kubeScheduler.enabled | bool | `true` |  |
| kubeScheduler.endpoints | list | `[]` |  |
| kubeScheduler.service.enabled | bool | `true` |  |
| kubeScheduler.service.port | string | `nil` |  |
| kubeScheduler.service.targetPort | string | `nil` |  |
| kubeScheduler.service.ipDualStack.enabled | bool | `false` |  |
| kubeScheduler.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| kubeScheduler.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| kubeScheduler.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| kubeScheduler.serviceMonitor.enabled | bool | `true` |  |
| kubeScheduler.serviceMonitor.interval | string | `""` |  |
| kubeScheduler.serviceMonitor.sampleLimit | int | `0` |  |
| kubeScheduler.serviceMonitor.targetLimit | int | `0` |  |
| kubeScheduler.serviceMonitor.labelLimit | int | `0` |  |
| kubeScheduler.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeScheduler.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeScheduler.serviceMonitor.proxyUrl | string | `""` |  |
| kubeScheduler.serviceMonitor.https | string | `nil` |  |
| kubeScheduler.serviceMonitor.port | string | `"http-metrics"` |  |
| kubeScheduler.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| kubeScheduler.serviceMonitor.selector | object | `{}` |  |
| kubeScheduler.serviceMonitor.insecureSkipVerify | string | `nil` |  |
| kubeScheduler.serviceMonitor.serverName | string | `nil` |  |
| kubeScheduler.serviceMonitor.metricRelabelings | list | `[]` |  |
| kubeScheduler.serviceMonitor.relabelings | list | `[]` |  |
| kubeScheduler.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeScheduler.serviceMonitor.targetLabels | list | `[]` |  |
| kubeProxy.enabled | bool | `true` |  |
| kubeProxy.endpoints | list | `[]` |  |
| kubeProxy.service.enabled | bool | `true` |  |
| kubeProxy.service.port | int | `10249` |  |
| kubeProxy.service.targetPort | int | `10249` |  |
| kubeProxy.service.ipDualStack.enabled | bool | `false` |  |
| kubeProxy.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| kubeProxy.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| kubeProxy.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| kubeProxy.serviceMonitor.enabled | bool | `true` |  |
| kubeProxy.serviceMonitor.interval | string | `""` |  |
| kubeProxy.serviceMonitor.sampleLimit | int | `0` |  |
| kubeProxy.serviceMonitor.targetLimit | int | `0` |  |
| kubeProxy.serviceMonitor.labelLimit | int | `0` |  |
| kubeProxy.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| kubeProxy.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| kubeProxy.serviceMonitor.proxyUrl | string | `""` |  |
| kubeProxy.serviceMonitor.port | string | `"http-metrics"` |  |
| kubeProxy.serviceMonitor.jobLabel | string | `"jobLabel"` |  |
| kubeProxy.serviceMonitor.selector | object | `{}` |  |
| kubeProxy.serviceMonitor.https | bool | `false` |  |
| kubeProxy.serviceMonitor.metricRelabelings | list | `[]` |  |
| kubeProxy.serviceMonitor.relabelings | list | `[]` |  |
| kubeProxy.serviceMonitor.additionalLabels | object | `{}` |  |
| kubeProxy.serviceMonitor.targetLabels | list | `[]` |  |
| kubeStateMetrics.enabled | bool | `true` |  |
| kube-state-metrics.image.registry | string | `"registry1.dso.mil"` |  |
| kube-state-metrics.image.repository | string | `"ironbank/opensource/kubernetes/kube-state-metrics"` |  |
| kube-state-metrics.image.tag | string | `"v2.15.0"` |  |
| kube-state-metrics.resources.limits.cpu | string | `"100m"` |  |
| kube-state-metrics.resources.limits.memory | string | `"128Mi"` |  |
| kube-state-metrics.resources.requests.cpu | string | `"100m"` |  |
| kube-state-metrics.resources.requests.memory | string | `"128Mi"` |  |
| kube-state-metrics.namespaceOverride | string | `""` |  |
| kube-state-metrics.rbac.create | bool | `true` |  |
| kube-state-metrics.podSecurityPolicy.enabled | bool | `false` |  |
| kube-state-metrics.securityContext.runAsGroup | int | `65532` |  |
| kube-state-metrics.securityContext.runAsUser | int | `65532` |  |
| kube-state-metrics.securityContext.fsGroup | int | `65532` |  |
| kube-state-metrics.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| kube-state-metrics.releaseLabel | bool | `true` |  |
| kube-state-metrics.prometheusScrape | bool | `false` |  |
| kube-state-metrics.prometheus.monitor.enabled | bool | `true` |  |
| kube-state-metrics.prometheus.monitor.interval | string | `""` |  |
| kube-state-metrics.prometheus.monitor.sampleLimit | int | `0` |  |
| kube-state-metrics.prometheus.monitor.targetLimit | int | `0` |  |
| kube-state-metrics.prometheus.monitor.labelLimit | int | `0` |  |
| kube-state-metrics.prometheus.monitor.labelNameLengthLimit | int | `0` |  |
| kube-state-metrics.prometheus.monitor.labelValueLengthLimit | int | `0` |  |
| kube-state-metrics.prometheus.monitor.scrapeTimeout | string | `""` |  |
| kube-state-metrics.prometheus.monitor.proxyUrl | string | `""` |  |
| kube-state-metrics.prometheus.monitor.honorLabels | bool | `true` |  |
| kube-state-metrics.prometheus.monitor.metricRelabelings | list | `[]` |  |
| kube-state-metrics.prometheus.monitor.relabelings | list | `[]` |  |
| kube-state-metrics.selfMonitor.enabled | bool | `false` |  |
| nodeExporter.enabled | bool | `true` |  |
| nodeExporter.operatingSystems.linux.enabled | bool | `true` |  |
| nodeExporter.operatingSystems.aix.enabled | bool | `true` |  |
| nodeExporter.operatingSystems.darwin.enabled | bool | `true` |  |
| nodeExporter.serviceMonitor.interval | string | `""` |  |
| nodeExporter.jobLabel | string | `"jobLabel"` |  |
| nodeExporter.forceDeployDashboards | bool | `false` |  |
| prometheus-node-exporter.serviceMonitor.attachMetadata | object | `{}` |  |
| prometheus-node-exporter.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheus-node-exporter.image.registry | string | `"registry1.dso.mil"` |  |
| prometheus-node-exporter.image.repository | string | `"ironbank/opensource/prometheus/node-exporter"` |  |
| prometheus-node-exporter.image.tag | string | `"v1.9.0"` |  |
| prometheus-node-exporter.resources.limits.cpu | string | `"200m"` |  |
| prometheus-node-exporter.resources.limits.memory | string | `"250Mi"` |  |
| prometheus-node-exporter.resources.requests.cpu | string | `"200m"` |  |
| prometheus-node-exporter.resources.requests.memory | string | `"250Mi"` |  |
| prometheus-node-exporter.hostNetwork | bool | `false` |  |
| prometheus-node-exporter.hostPID | bool | `false` |  |
| prometheus-node-exporter.namespaceOverride | string | `""` |  |
| prometheus-node-exporter.podLabels.jobLabel | string | `"node-exporter"` |  |
| prometheus-node-exporter.releaseLabel | bool | `true` |  |
| prometheus-node-exporter.extraArgs[0] | string | `"--collector.filesystem.mount-points-exclude=^/(dev\|proc\|sys\|var/lib/docker/.+\|var/lib/kubelet/.+)($\|/)"` |  |
| prometheus-node-exporter.extraArgs[1] | string | `"--collector.filesystem.fs-types-exclude=^(autofs\|binfmt_misc\|bpf\|cgroup2?\|configfs\|debugfs\|devpts\|devtmpfs\|fusectl\|hugetlbfs\|iso9660\|mqueue\|nsfs\|overlay\|proc\|procfs\|pstore\|rpc_pipefs\|securityfs\|selinuxfs\|squashfs\|sysfs\|tracefs)$"` |  |
| prometheus-node-exporter.service.portName | string | `"http-metrics"` |  |
| prometheus-node-exporter.service.ipDualStack.enabled | bool | `false` |  |
| prometheus-node-exporter.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheus-node-exporter.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheus-node-exporter.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheus-node-exporter.service.labels.jobLabel | string | `"node-exporter"` |  |
| prometheus-node-exporter.prometheus.monitor.enabled | bool | `true` |  |
| prometheus-node-exporter.prometheus.monitor.jobLabel | string | `"jobLabel"` |  |
| prometheus-node-exporter.prometheus.monitor.interval | string | `""` |  |
| prometheus-node-exporter.prometheus.monitor.sampleLimit | int | `0` |  |
| prometheus-node-exporter.prometheus.monitor.targetLimit | int | `0` |  |
| prometheus-node-exporter.prometheus.monitor.labelLimit | int | `0` |  |
| prometheus-node-exporter.prometheus.monitor.labelNameLengthLimit | int | `0` |  |
| prometheus-node-exporter.prometheus.monitor.labelValueLengthLimit | int | `0` |  |
| prometheus-node-exporter.prometheus.monitor.scrapeTimeout | string | `""` |  |
| prometheus-node-exporter.prometheus.monitor.proxyUrl | string | `""` |  |
| prometheus-node-exporter.prometheus.monitor.metricRelabelings | list | `[]` |  |
| prometheus-node-exporter.prometheus.monitor.relabelings | list | `[]` |  |
| prometheus-node-exporter.rbac.pspEnabled | bool | `false` |  |
| snmpExporter.enabled | bool | `false` |  |
| snmpExporter.image.repository | string | `"registry1.dso.mil/ironbank/opensource/prometheus/snmp_exporter"` |  |
| snmpExporter.image.tag | string | `"v0.28.0"` |  |
| snmpExporter.imagePullSecrets[0].name | string | `"private-registry"` |  |
| snmpExporter.configmapReload.image.repository | string | `"registry1.dso.mil/ironbank/opensource/prometheus-operator/prometheus-config-reloader"` |  |
| snmpExporter.configmapReload.image.tag | string | `"v0.80.1"` |  |
| snmpExporter.securityContext.runAsNonRoot | bool | `true` |  |
| snmpExporter.securityContext.runAsUser | int | `1001` |  |
| snmpExporter.securityContext.runAsGroup | int | `1001` |  |
| snmpExporter.securityContext.fsGroup | int | `1001` |  |
| snmpExporter.containerSecurityContext.runAsGroup | int | `1001` |  |
| snmpExporter.containerSecurityContext.runAsNonRoot | bool | `true` |  |
| snmpExporter.containerSecurityContext.runAsUser | int | `1001` |  |
| snmpExporter.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| snmpExporter.serviceMonitor.enabled | bool | `true` |  |
| prometheusOperator.enabled | bool | `true` |  |
| prometheusOperator.fullnameOverride | string | `""` |  |
| prometheusOperator.revisionHistoryLimit | int | `10` |  |
| prometheusOperator.strategy | object | `{}` |  |
| prometheusOperator.tls.enabled | bool | `true` |  |
| prometheusOperator.tls.tlsMinVersion | string | `"VersionTLS13"` |  |
| prometheusOperator.tls.internalPort | int | `10250` |  |
| prometheusOperator.livenessProbe.enabled | bool | `true` |  |
| prometheusOperator.livenessProbe.failureThreshold | int | `3` |  |
| prometheusOperator.livenessProbe.initialDelaySeconds | int | `0` |  |
| prometheusOperator.livenessProbe.periodSeconds | int | `10` |  |
| prometheusOperator.livenessProbe.successThreshold | int | `1` |  |
| prometheusOperator.livenessProbe.timeoutSeconds | int | `1` |  |
| prometheusOperator.readinessProbe.enabled | bool | `true` |  |
| prometheusOperator.readinessProbe.failureThreshold | int | `3` |  |
| prometheusOperator.readinessProbe.initialDelaySeconds | int | `0` |  |
| prometheusOperator.readinessProbe.periodSeconds | int | `10` |  |
| prometheusOperator.readinessProbe.successThreshold | int | `1` |  |
| prometheusOperator.readinessProbe.timeoutSeconds | int | `1` |  |
| prometheusOperator.admissionWebhooks.failurePolicy | string | `""` |  |
| prometheusOperator.admissionWebhooks.timeoutSeconds | int | `10` |  |
| prometheusOperator.admissionWebhooks.enabled | bool | `true` |  |
| prometheusOperator.admissionWebhooks.caBundle | string | `""` |  |
| prometheusOperator.admissionWebhooks.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.admissionWebhooks.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.namespaceSelector | object | `{}` |  |
| prometheusOperator.admissionWebhooks.objectSelector | object | `{}` |  |
| prometheusOperator.admissionWebhooks.mutatingWebhookConfiguration.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.validatingWebhookConfiguration.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.enabled | bool | `false` |  |
| prometheusOperator.admissionWebhooks.deployment.replicas | int | `1` |  |
| prometheusOperator.admissionWebhooks.deployment.strategy | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.podDisruptionBudget | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.revisionHistoryLimit | int | `10` |  |
| prometheusOperator.admissionWebhooks.deployment.tls.enabled | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.tls.tlsMinVersion | string | `"VersionTLS13"` |  |
| prometheusOperator.admissionWebhooks.deployment.tls.internalPort | int | `10250` |  |
| prometheusOperator.admissionWebhooks.deployment.serviceAccount.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.serviceAccount.automountServiceAccountToken | bool | `false` |  |
| prometheusOperator.admissionWebhooks.deployment.serviceAccount.create | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.serviceAccount.name | string | `""` |  |
| prometheusOperator.admissionWebhooks.deployment.service.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.service.labels | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.service.clusterIP | string | `""` |  |
| prometheusOperator.admissionWebhooks.deployment.service.ipDualStack.enabled | bool | `false` |  |
| prometheusOperator.admissionWebhooks.deployment.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheusOperator.admissionWebhooks.deployment.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheusOperator.admissionWebhooks.deployment.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheusOperator.admissionWebhooks.deployment.service.nodePort | int | `31080` |  |
| prometheusOperator.admissionWebhooks.deployment.service.nodePortTls | int | `31443` |  |
| prometheusOperator.admissionWebhooks.deployment.service.additionalPorts | list | `[]` |  |
| prometheusOperator.admissionWebhooks.deployment.service.loadBalancerIP | string | `""` |  |
| prometheusOperator.admissionWebhooks.deployment.service.loadBalancerSourceRanges | list | `[]` |  |
| prometheusOperator.admissionWebhooks.deployment.service.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheusOperator.admissionWebhooks.deployment.service.type | string | `"ClusterIP"` |  |
| prometheusOperator.admissionWebhooks.deployment.service.externalIPs | list | `[]` |  |
| prometheusOperator.admissionWebhooks.deployment.labels | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.podLabels | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.podAnnotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.image.registry | string | `"quay.io"` |  |
| prometheusOperator.admissionWebhooks.deployment.image.repository | string | `"prometheus-operator/admission-webhook"` |  |
| prometheusOperator.admissionWebhooks.deployment.image.tag | string | `""` |  |
| prometheusOperator.admissionWebhooks.deployment.image.sha | string | `""` |  |
| prometheusOperator.admissionWebhooks.deployment.image.pullPolicy | string | `"IfNotPresent"` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.enabled | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.failureThreshold | int | `3` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.initialDelaySeconds | int | `30` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.periodSeconds | int | `10` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.successThreshold | int | `1` |  |
| prometheusOperator.admissionWebhooks.deployment.livenessProbe.timeoutSeconds | int | `1` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.enabled | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.failureThreshold | int | `3` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.initialDelaySeconds | int | `5` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.periodSeconds | int | `10` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.successThreshold | int | `1` |  |
| prometheusOperator.admissionWebhooks.deployment.readinessProbe.timeoutSeconds | int | `1` |  |
| prometheusOperator.admissionWebhooks.deployment.resources | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.hostNetwork | bool | `false` |  |
| prometheusOperator.admissionWebhooks.deployment.nodeSelector | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.tolerations | list | `[]` |  |
| prometheusOperator.admissionWebhooks.deployment.affinity | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.dnsConfig | object | `{}` |  |
| prometheusOperator.admissionWebhooks.deployment.securityContext.fsGroup | int | `65534` |  |
| prometheusOperator.admissionWebhooks.deployment.securityContext.runAsGroup | int | `65534` |  |
| prometheusOperator.admissionWebhooks.deployment.securityContext.runAsNonRoot | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.securityContext.runAsUser | int | `65534` |  |
| prometheusOperator.admissionWebhooks.deployment.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| prometheusOperator.admissionWebhooks.deployment.containerSecurityContext.allowPrivilegeEscalation | bool | `false` |  |
| prometheusOperator.admissionWebhooks.deployment.containerSecurityContext.readOnlyRootFilesystem | bool | `true` |  |
| prometheusOperator.admissionWebhooks.deployment.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.admissionWebhooks.deployment.automountServiceAccountToken | bool | `true` |  |
| prometheusOperator.admissionWebhooks.patch.enabled | bool | `true` |  |
| prometheusOperator.admissionWebhooks.patch.image.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.admissionWebhooks.patch.image.repository | string | `"ironbank/opensource/ingress-nginx/kube-webhook-certgen"` |  |
| prometheusOperator.admissionWebhooks.patch.image.tag | string | `"v1.5.1"` |  |
| prometheusOperator.admissionWebhooks.patch.image.sha | string | `""` |  |
| prometheusOperator.admissionWebhooks.patch.image.pullPolicy | string | `"IfNotPresent"` |  |
| prometheusOperator.admissionWebhooks.patch.resources.limits.cpu | string | `"50m"` |  |
| prometheusOperator.admissionWebhooks.patch.resources.limits.memory | string | `"50Mi"` |  |
| prometheusOperator.admissionWebhooks.patch.resources.requests.cpu | string | `"50m"` |  |
| prometheusOperator.admissionWebhooks.patch.resources.requests.memory | string | `"50Mi"` |  |
| prometheusOperator.admissionWebhooks.patch.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.admissionWebhooks.patch.securityContext.runAsNonRoot | bool | `true` |  |
| prometheusOperator.admissionWebhooks.patch.securityContext.runAsUser | int | `65532` |  |
| prometheusOperator.admissionWebhooks.patch.securityContext.runAsGroup | int | `65532` |  |
| prometheusOperator.admissionWebhooks.patch.priorityClassName | string | `""` |  |
| prometheusOperator.admissionWebhooks.patch.ttlSecondsAfterFinished | int | `60` |  |
| prometheusOperator.admissionWebhooks.patch.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.patch.podAnnotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.patch.nodeSelector | object | `{}` |  |
| prometheusOperator.admissionWebhooks.patch.affinity | object | `{}` |  |
| prometheusOperator.admissionWebhooks.patch.tolerations | list | `[]` |  |
| prometheusOperator.admissionWebhooks.patch.serviceAccount.create | bool | `true` |  |
| prometheusOperator.admissionWebhooks.patch.serviceAccount.automountServiceAccountToken | bool | `true` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.image.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.image.repository | string | `"ironbank/big-bang/base"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.image.tag | string | `"2.1.0"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.image.sha | string | `""` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.image.pullPolicy | string | `"IfNotPresent"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.resources.limits.cpu | string | `"50m"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.resources.limits.memory | string | `"50Mi"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.resources.requests.cpu | string | `"50m"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.resources.requests.memory | string | `"50Mi"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.priorityClassName | string | `""` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.ttlSecondsAfterFinished | int | `60` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.podAnnotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.nodeSelector | object | `{}` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.affinity | object | `{}` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.tolerations | list | `[]` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.securityContext.runAsGroup | int | `2000` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.securityContext.runAsNonRoot | bool | `true` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.securityContext.runAsUser | int | `2000` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.serviceAccount.create | bool | `true` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.serviceAccount.annotations | object | `{}` |  |
| prometheusOperator.admissionWebhooks.cleanupProxy.serviceAccount.automountServiceAccountToken | bool | `true` |  |
| prometheusOperator.admissionWebhooks.createSecretJob.securityContext.allowPrivilegeEscalation | bool | `false` |  |
| prometheusOperator.admissionWebhooks.createSecretJob.securityContext.readOnlyRootFilesystem | bool | `true` |  |
| prometheusOperator.admissionWebhooks.createSecretJob.securityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.admissionWebhooks.patchWebhookJob.securityContext.allowPrivilegeEscalation | bool | `false` |  |
| prometheusOperator.admissionWebhooks.patchWebhookJob.securityContext.readOnlyRootFilesystem | bool | `true` |  |
| prometheusOperator.admissionWebhooks.patchWebhookJob.securityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.admissionWebhooks.certManager.enabled | bool | `false` |  |
| prometheusOperator.admissionWebhooks.certManager.rootCert.duration | string | `""` |  |
| prometheusOperator.admissionWebhooks.certManager.rootCert.revisionHistoryLimit | string | `nil` | Set the revisionHistoryLimit on the Certificate. See https://cert-manager.io/docs/reference/api-docs/#cert-manager.io/v1.CertificateSpec Defaults to nil. |
| prometheusOperator.admissionWebhooks.certManager.admissionCert.duration | string | `""` |  |
| prometheusOperator.admissionWebhooks.certManager.admissionCert.revisionHistoryLimit | string | `nil` | Set the revisionHistoryLimit on the Certificate. See https://cert-manager.io/docs/reference/api-docs/#cert-manager.io/v1.CertificateSpec Defaults to nil. |
| prometheusOperator.namespaces | object | `{}` |  |
| prometheusOperator.denyNamespaces | list | `[]` |  |
| prometheusOperator.alertmanagerInstanceNamespaces | list | `[]` |  |
| prometheusOperator.alertmanagerConfigNamespaces | list | `[]` |  |
| prometheusOperator.prometheusInstanceNamespaces | list | `[]` |  |
| prometheusOperator.thanosRulerInstanceNamespaces | list | `[]` |  |
| prometheusOperator.clusterDomain | string | `"cluster.local"` |  |
| prometheusOperator.networkPolicy.enabled | bool | `false` |  |
| prometheusOperator.networkPolicy.flavor | string | `"kubernetes"` |  |
| prometheusOperator.serviceAccount.create | bool | `true` |  |
| prometheusOperator.serviceAccount.name | string | `""` |  |
| prometheusOperator.serviceAccount.automountServiceAccountToken | bool | `true` |  |
| prometheusOperator.serviceAccount.annotations | object | `{}` |  |
| prometheusOperator.terminationGracePeriodSeconds | int | `30` | terminationGracePeriodSeconds for container lifecycle hook |
| prometheusOperator.lifecycle | object | `{}` | Specify lifecycle hooks for the  controller |
| prometheusOperator.service.annotations | object | `{}` |  |
| prometheusOperator.service.labels | object | `{}` |  |
| prometheusOperator.service.clusterIP | string | `""` |  |
| prometheusOperator.service.ipDualStack.enabled | bool | `false` |  |
| prometheusOperator.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheusOperator.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheusOperator.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheusOperator.service.nodePort | int | `30080` |  |
| prometheusOperator.service.nodePortTls | int | `30443` |  |
| prometheusOperator.service.additionalPorts | list | `[]` |  |
| prometheusOperator.service.loadBalancerIP | string | `""` |  |
| prometheusOperator.service.loadBalancerSourceRanges | list | `[]` |  |
| prometheusOperator.service.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheusOperator.service.type | string | `"ClusterIP"` |  |
| prometheusOperator.service.externalIPs | list | `[]` |  |
| prometheusOperator.labels | object | `{}` |  |
| prometheusOperator.annotations | object | `{}` |  |
| prometheusOperator.podLabels | object | `{}` |  |
| prometheusOperator.podAnnotations | object | `{}` |  |
| prometheusOperator.kubeletService.enabled | bool | `true` |  |
| prometheusOperator.kubeletService.namespace | string | `"kube-system"` |  |
| prometheusOperator.kubeletService.selector | string | `""` |  |
| prometheusOperator.kubeletService.name | string | `""` |  |
| prometheusOperator.kubeletEndpointsEnabled | bool | `true` |  |
| prometheusOperator.kubeletEndpointSliceEnabled | bool | `false` |  |
| prometheusOperator.extraArgs | list | `[]` |  |
| prometheusOperator.serviceMonitor.selfMonitor | bool | `true` |  |
| prometheusOperator.serviceMonitor.additionalLabels | object | `{}` |  |
| prometheusOperator.serviceMonitor.interval | string | `""` |  |
| prometheusOperator.serviceMonitor.sampleLimit | int | `0` |  |
| prometheusOperator.serviceMonitor.targetLimit | int | `0` |  |
| prometheusOperator.serviceMonitor.labelLimit | int | `0` |  |
| prometheusOperator.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| prometheusOperator.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| prometheusOperator.serviceMonitor.scrapeTimeout | string | `""` |  |
| prometheusOperator.serviceMonitor.metricRelabelings | list | `[]` |  |
| prometheusOperator.serviceMonitor.relabelings | list | `[]` |  |
| prometheusOperator.resources.limits.cpu | string | `"200m"` |  |
| prometheusOperator.resources.limits.memory | string | `"512Mi"` |  |
| prometheusOperator.resources.requests.cpu | string | `"200m"` |  |
| prometheusOperator.resources.requests.memory | string | `"512Mi"` |  |
| prometheusOperator.env.GOGC | string | `"30"` |  |
| prometheusOperator.hostNetwork | bool | `false` |  |
| prometheusOperator.nodeSelector | object | `{}` |  |
| prometheusOperator.tolerations | list | `[]` |  |
| prometheusOperator.affinity | object | `{}` |  |
| prometheusOperator.dnsConfig | object | `{}` |  |
| prometheusOperator.securityContext.fsGroup | int | `65534` |  |
| prometheusOperator.securityContext.runAsGroup | int | `65534` |  |
| prometheusOperator.securityContext.runAsNonRoot | bool | `true` |  |
| prometheusOperator.securityContext.runAsUser | int | `65534` |  |
| prometheusOperator.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| prometheusOperator.containerSecurityContext.allowPrivilegeEscalation | bool | `false` |  |
| prometheusOperator.containerSecurityContext.readOnlyRootFilesystem | bool | `true` |  |
| prometheusOperator.containerSecurityContext.capabilities.drop[0] | string | `"ALL"` |  |
| prometheusOperator.verticalPodAutoscaler.enabled | bool | `false` |  |
| prometheusOperator.verticalPodAutoscaler.controlledResources | list | `[]` |  |
| prometheusOperator.verticalPodAutoscaler.maxAllowed | object | `{}` |  |
| prometheusOperator.verticalPodAutoscaler.minAllowed | object | `{}` |  |
| prometheusOperator.verticalPodAutoscaler.updatePolicy.updateMode | string | `"Auto"` |  |
| prometheusOperator.image.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.image.repository | string | `"ironbank/opensource/prometheus-operator/prometheus-operator"` |  |
| prometheusOperator.image.tag | string | `"v0.80.1"` |  |
| prometheusOperator.image.sha | string | `""` |  |
| prometheusOperator.image.pullPolicy | string | `"IfNotPresent"` |  |
| prometheusOperator.prometheusConfigReloader.image.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.prometheusConfigReloader.image.repository | string | `"ironbank/opensource/prometheus-operator/prometheus-config-reloader"` |  |
| prometheusOperator.prometheusConfigReloader.image.tag | string | `"v0.80.1"` |  |
| prometheusOperator.prometheusConfigReloader.image.sha | string | `""` |  |
| prometheusOperator.prometheusConfigReloader.enableProbe | bool | `false` |  |
| prometheusOperator.prometheusConfigReloader.resources | object | `{}` |  |
| prometheusOperator.thanosImage.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.thanosImage.repository | string | `"ironbank/opensource/thanos/thanos"` |  |
| prometheusOperator.thanosImage.tag | string | `"v0.37.2"` |  |
| prometheusOperator.thanosImage.sha | string | `""` |  |
| prometheusOperator.prometheusInstanceSelector | string | `""` |  |
| prometheusOperator.alertmanagerInstanceSelector | string | `""` |  |
| prometheusOperator.thanosRulerInstanceSelector | string | `""` |  |
| prometheusOperator.secretFieldSelector | string | `"type!=kubernetes.io/dockercfg,type!=kubernetes.io/service-account-token,type!=helm.sh/release.v1"` |  |
| prometheusOperator.kubectlImage.registry | string | `"registry1.dso.mil"` |  |
| prometheusOperator.kubectlImage.repository | string | `"ironbank/opensource/kubernetes/kubectl"` |  |
| prometheusOperator.kubectlImage.tag | string | `"v1.30.10"` |  |
| prometheusOperator.kubectlImage.sha | string | `""` |  |
| prometheusOperator.kubectlImage.pullPolicy | string | `"IfNotPresent"` |  |
| prometheusOperator.automountServiceAccountToken | bool | `true` |  |
| prometheusOperator.extraVolumes | list | `[]` |  |
| prometheusOperator.extraVolumeMounts | list | `[]` |  |
| prometheus.enabled | bool | `true` |  |
| prometheus.agentMode | bool | `false` |  |
| prometheus.annotations | object | `{}` |  |
| prometheus.networkPolicy.enabled | bool | `false` |  |
| prometheus.networkPolicy.flavor | string | `"kubernetes"` |  |
| prometheus.serviceAccount.create | bool | `true` |  |
| prometheus.serviceAccount.name | string | `""` |  |
| prometheus.serviceAccount.annotations | object | `{}` |  |
| prometheus.serviceAccount.automountServiceAccountToken | bool | `true` |  |
| prometheus.thanosService.enabled | bool | `false` |  |
| prometheus.thanosService.annotations | object | `{}` |  |
| prometheus.thanosService.labels | object | `{}` |  |
| prometheus.thanosService.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheus.thanosService.type | string | `"ClusterIP"` |  |
| prometheus.thanosService.ipDualStack.enabled | bool | `false` |  |
| prometheus.thanosService.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheus.thanosService.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheus.thanosService.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheus.thanosService.portName | string | `"grpc"` |  |
| prometheus.thanosService.port | int | `10901` |  |
| prometheus.thanosService.targetPort | string | `"grpc"` |  |
| prometheus.thanosService.httpPortName | string | `"http"` |  |
| prometheus.thanosService.httpPort | int | `10902` |  |
| prometheus.thanosService.targetHttpPort | string | `"http"` |  |
| prometheus.thanosService.clusterIP | string | `"None"` |  |
| prometheus.thanosService.nodePort | int | `30901` |  |
| prometheus.thanosService.httpNodePort | int | `30902` |  |
| prometheus.thanosServiceMonitor.enabled | bool | `false` |  |
| prometheus.thanosServiceMonitor.interval | string | `""` |  |
| prometheus.thanosServiceMonitor.additionalLabels | object | `{}` |  |
| prometheus.thanosServiceMonitor.scheme | string | `""` |  |
| prometheus.thanosServiceMonitor.tlsConfig | object | `{}` |  |
| prometheus.thanosServiceMonitor.bearerTokenFile | string | `nil` |  |
| prometheus.thanosServiceMonitor.metricRelabelings | list | `[]` |  |
| prometheus.thanosServiceMonitor.relabelings | list | `[]` |  |
| prometheus.thanosServiceExternal.enabled | bool | `false` |  |
| prometheus.thanosServiceExternal.annotations | object | `{}` |  |
| prometheus.thanosServiceExternal.labels | object | `{}` |  |
| prometheus.thanosServiceExternal.loadBalancerIP | string | `""` |  |
| prometheus.thanosServiceExternal.loadBalancerSourceRanges | list | `[]` |  |
| prometheus.thanosServiceExternal.portName | string | `"grpc"` |  |
| prometheus.thanosServiceExternal.port | int | `10901` |  |
| prometheus.thanosServiceExternal.targetPort | string | `"grpc"` |  |
| prometheus.thanosServiceExternal.httpPortName | string | `"http"` |  |
| prometheus.thanosServiceExternal.httpPort | int | `10902` |  |
| prometheus.thanosServiceExternal.targetHttpPort | string | `"http"` |  |
| prometheus.thanosServiceExternal.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheus.thanosServiceExternal.type | string | `"LoadBalancer"` |  |
| prometheus.thanosServiceExternal.nodePort | int | `30901` |  |
| prometheus.thanosServiceExternal.httpNodePort | int | `30902` |  |
| prometheus.service.annotations | object | `{}` |  |
| prometheus.service.labels | object | `{}` |  |
| prometheus.service.clusterIP | string | `""` |  |
| prometheus.service.ipDualStack.enabled | bool | `false` |  |
| prometheus.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheus.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheus.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheus.service.port | int | `9090` |  |
| prometheus.service.targetPort | int | `9090` |  |
| prometheus.service.reloaderWebPort | int | `8080` |  |
| prometheus.service.externalIPs | list | `[]` |  |
| prometheus.service.nodePort | int | `30090` |  |
| prometheus.service.loadBalancerIP | string | `""` |  |
| prometheus.service.loadBalancerSourceRanges | list | `[]` |  |
| prometheus.service.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheus.service.type | string | `"ClusterIP"` |  |
| prometheus.service.additionalPorts | list | `[]` |  |
| prometheus.service.publishNotReadyAddresses | bool | `false` |  |
| prometheus.service.sessionAffinity | string | `"None"` |  |
| prometheus.service.sessionAffinityConfig.clientIP.timeoutSeconds | int | `10800` |  |
| prometheus.servicePerReplica.enabled | bool | `false` |  |
| prometheus.servicePerReplica.annotations | object | `{}` |  |
| prometheus.servicePerReplica.port | int | `9090` |  |
| prometheus.servicePerReplica.targetPort | int | `9090` |  |
| prometheus.servicePerReplica.nodePort | int | `30091` |  |
| prometheus.servicePerReplica.loadBalancerSourceRanges | list | `[]` |  |
| prometheus.servicePerReplica.externalTrafficPolicy | string | `"Cluster"` |  |
| prometheus.servicePerReplica.type | string | `"ClusterIP"` |  |
| prometheus.servicePerReplica.ipDualStack.enabled | bool | `false` |  |
| prometheus.servicePerReplica.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| prometheus.servicePerReplica.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| prometheus.servicePerReplica.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| prometheus.podDisruptionBudget.enabled | bool | `false` |  |
| prometheus.podDisruptionBudget.minAvailable | int | `1` |  |
| prometheus.podDisruptionBudget.maxUnavailable | string | `""` |  |
| prometheus.thanosIngress.enabled | bool | `false` |  |
| prometheus.thanosIngress.annotations | object | `{}` |  |
| prometheus.thanosIngress.labels | object | `{}` |  |
| prometheus.thanosIngress.servicePort | int | `10901` |  |
| prometheus.thanosIngress.nodePort | int | `30901` |  |
| prometheus.thanosIngress.hosts | list | `[]` |  |
| prometheus.thanosIngress.paths | list | `[]` |  |
| prometheus.thanosIngress.tls | list | `[]` |  |
| prometheus.extraSecret.annotations | object | `{}` |  |
| prometheus.extraSecret.data | object | `{}` |  |
| prometheus.ingress.enabled | bool | `false` |  |
| prometheus.ingress.annotations | object | `{}` |  |
| prometheus.ingress.labels | object | `{}` |  |
| prometheus.ingress.hosts | list | `[]` |  |
| prometheus.ingress.paths | list | `[]` |  |
| prometheus.ingress.tls | list | `[]` |  |
| prometheus.route | object | `{"main":{"additionalRules":[],"annotations":{},"apiVersion":"gateway.networking.k8s.io/v1","enabled":false,"filters":[],"hostnames":[],"httpsRedirect":false,"kind":"HTTPRoute","labels":{},"matches":[{"path":{"type":"PathPrefix","value":"/"}}],"parentRefs":[]}}` | BETA: Configure the gateway routes for the chart here. More routes can be added by adding a dictionary key like the 'main' route. Be aware that this is an early beta of this feature, kube-prometheus-stack does not guarantee this works and is subject to change. Being BETA this can/will change in the future without notice, do not use unless you want to take that risk [[ref]](https://gateway-api.sigs.k8s.io/references/spec/#gateway.networking.k8s.io%2fv1alpha2) |
| prometheus.route.main.enabled | bool | `false` | Enables or disables the route |
| prometheus.route.main.apiVersion | string | `"gateway.networking.k8s.io/v1"` | Set the route apiVersion, e.g. gateway.networking.k8s.io/v1 or gateway.networking.k8s.io/v1alpha2 |
| prometheus.route.main.kind | string | `"HTTPRoute"` | Set the route kind Valid options are GRPCRoute, HTTPRoute, TCPRoute, TLSRoute, UDPRoute |
| prometheus.route.main.httpsRedirect | bool | `false` | create http route for redirect (https://gateway-api.sigs.k8s.io/guides/http-redirect-rewrite/#http-to-https-redirects) # Take care that you only enable this on the http listener of the gateway to avoid an infinite redirect. # matches, filters and additionalRules will be ignored if this is set to true. Be are |
| prometheus.ingressPerReplica.enabled | bool | `false` |  |
| prometheus.ingressPerReplica.annotations | object | `{}` |  |
| prometheus.ingressPerReplica.labels | object | `{}` |  |
| prometheus.ingressPerReplica.hostPrefix | string | `""` |  |
| prometheus.ingressPerReplica.hostDomain | string | `""` |  |
| prometheus.ingressPerReplica.paths | list | `[]` |  |
| prometheus.ingressPerReplica.tlsSecretName | string | `""` |  |
| prometheus.ingressPerReplica.tlsSecretPerReplica.enabled | bool | `false` |  |
| prometheus.ingressPerReplica.tlsSecretPerReplica.prefix | string | `"prometheus"` |  |
| prometheus.podSecurityPolicy.allowedCapabilities | list | `[]` |  |
| prometheus.podSecurityPolicy.allowedHostPaths | list | `[]` |  |
| prometheus.podSecurityPolicy.volumes | list | `[]` |  |
| prometheus.serviceMonitor.selfMonitor | bool | `true` |  |
| prometheus.serviceMonitor.interval | string | `""` |  |
| prometheus.serviceMonitor.additionalLabels | object | `{}` |  |
| prometheus.serviceMonitor.sampleLimit | int | `0` |  |
| prometheus.serviceMonitor.targetLimit | int | `0` |  |
| prometheus.serviceMonitor.labelLimit | int | `0` |  |
| prometheus.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| prometheus.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| prometheus.serviceMonitor.scheme | string | `""` |  |
| prometheus.serviceMonitor.tlsConfig | object | `{}` |  |
| prometheus.serviceMonitor.bearerTokenFile | string | `nil` |  |
| prometheus.serviceMonitor.metricRelabelings | list | `[]` |  |
| prometheus.serviceMonitor.relabelings | list | `[]` |  |
| prometheus.serviceMonitor.additionalEndpoints | list | `[]` |  |
| prometheus.prometheusSpec.persistentVolumeClaimRetentionPolicy | object | `{}` |  |
| prometheus.prometheusSpec.disableCompaction | bool | `false` |  |
| prometheus.prometheusSpec.automountServiceAccountToken | bool | `true` |  |
| prometheus.prometheusSpec.apiserverConfig | object | `{}` |  |
| prometheus.prometheusSpec.additionalArgs | list | `[]` |  |
| prometheus.prometheusSpec.scrapeFailureLogFile | string | `""` |  |
| prometheus.prometheusSpec.scrapeInterval | string | `""` |  |
| prometheus.prometheusSpec.scrapeTimeout | string | `""` |  |
| prometheus.prometheusSpec.scrapeClasses | list | `[]` |  |
| prometheus.prometheusSpec.evaluationInterval | string | `""` |  |
| prometheus.prometheusSpec.listenLocal | bool | `false` |  |
| prometheus.prometheusSpec.enableAdminAPI | bool | `false` |  |
| prometheus.prometheusSpec.version | string | `""` |  |
| prometheus.prometheusSpec.web | object | `{}` |  |
| prometheus.prometheusSpec.exemplars | object | `{}` |  |
| prometheus.prometheusSpec.enableFeatures | list | `[]` |  |
| prometheus.prometheusSpec.image.registry | string | `"registry1.dso.mil"` |  |
| prometheus.prometheusSpec.image.repository | string | `"ironbank/opensource/prometheus/prometheus"` |  |
| prometheus.prometheusSpec.image.tag | string | `"v3.2.1"` |  |
| prometheus.prometheusSpec.image.sha | string | `""` |  |
| prometheus.prometheusSpec.tolerations | list | `[]` |  |
| prometheus.prometheusSpec.topologySpreadConstraints | list | `[]` |  |
| prometheus.prometheusSpec.alertingEndpoints | list | `[]` |  |
| prometheus.prometheusSpec.externalLabels | object | `{}` |  |
| prometheus.prometheusSpec.enableRemoteWriteReceiver | bool | `false` |  |
| prometheus.prometheusSpec.replicaExternalLabelName | string | `""` |  |
| prometheus.prometheusSpec.replicaExternalLabelNameClear | bool | `false` |  |
| prometheus.prometheusSpec.prometheusExternalLabelName | string | `""` |  |
| prometheus.prometheusSpec.prometheusExternalLabelNameClear | bool | `false` |  |
| prometheus.prometheusSpec.externalUrl | string | `"https://prometheus.{{ .Values.domain }}"` |  |
| prometheus.prometheusSpec.nodeSelector | object | `{}` |  |
| prometheus.prometheusSpec.secrets | list | `[]` |  |
| prometheus.prometheusSpec.configMaps | list | `[]` |  |
| prometheus.prometheusSpec.query | object | `{}` |  |
| prometheus.prometheusSpec.ruleNamespaceSelector | object | `{}` |  |
| prometheus.prometheusSpec.ruleSelectorNilUsesHelmValues | bool | `false` |  |
| prometheus.prometheusSpec.ruleSelector | object | `{}` |  |
| prometheus.prometheusSpec.serviceMonitorSelectorNilUsesHelmValues | bool | `false` |  |
| prometheus.prometheusSpec.serviceMonitorSelector | object | `{}` |  |
| prometheus.prometheusSpec.serviceMonitorNamespaceSelector | object | `{}` |  |
| prometheus.prometheusSpec.podMonitorSelectorNilUsesHelmValues | bool | `false` |  |
| prometheus.prometheusSpec.podMonitorSelector | object | `{}` |  |
| prometheus.prometheusSpec.podMonitorNamespaceSelector | object | `{}` |  |
| prometheus.prometheusSpec.probeSelectorNilUsesHelmValues | bool | `false` |  |
| prometheus.prometheusSpec.probeSelector | object | `{}` |  |
| prometheus.prometheusSpec.probeNamespaceSelector | object | `{}` |  |
| prometheus.prometheusSpec.scrapeConfigSelectorNilUsesHelmValues | bool | `true` |  |
| prometheus.prometheusSpec.scrapeConfigSelector | object | `{}` |  |
| prometheus.prometheusSpec.scrapeConfigNamespaceSelector | object | `{}` |  |
| prometheus.prometheusSpec.retention | string | `"10d"` |  |
| prometheus.prometheusSpec.retentionSize | string | `""` |  |
| prometheus.prometheusSpec.tsdb.outOfOrderTimeWindow | string | `"0s"` |  |
| prometheus.prometheusSpec.walCompression | bool | `true` |  |
| prometheus.prometheusSpec.paused | bool | `false` |  |
| prometheus.prometheusSpec.replicas | int | `1` |  |
| prometheus.prometheusSpec.shards | int | `1` |  |
| prometheus.prometheusSpec.logLevel | string | `"info"` |  |
| prometheus.prometheusSpec.logFormat | string | `"logfmt"` |  |
| prometheus.prometheusSpec.routePrefix | string | `"/"` |  |
| prometheus.prometheusSpec.podMetadata.labels.app | string | `"prometheus"` |  |
| prometheus.prometheusSpec.podAntiAffinity | string | `"soft"` |  |
| prometheus.prometheusSpec.podAntiAffinityTopologyKey | string | `"kubernetes.io/hostname"` |  |
| prometheus.prometheusSpec.affinity | object | `{}` |  |
| prometheus.prometheusSpec.remoteRead | list | `[]` |  |
| prometheus.prometheusSpec.additionalRemoteRead | list | `[]` |  |
| prometheus.prometheusSpec.remoteWrite | list | `[]` |  |
| prometheus.prometheusSpec.additionalRemoteWrite | list | `[]` |  |
| prometheus.prometheusSpec.remoteWriteDashboards | bool | `false` |  |
| prometheus.prometheusSpec.resources.limits.cpu | string | `"300m"` |  |
| prometheus.prometheusSpec.resources.limits.memory | string | `"5Gi"` |  |
| prometheus.prometheusSpec.resources.requests.cpu | string | `"300m"` |  |
| prometheus.prometheusSpec.resources.requests.memory | string | `"5Gi"` |  |
| prometheus.prometheusSpec.storageSpec | object | `{}` |  |
| prometheus.prometheusSpec.volumes | list | `[]` |  |
| prometheus.prometheusSpec.volumeMounts | list | `[]` |  |
| prometheus.prometheusSpec.additionalScrapeConfigs | list | `[]` |  |
| prometheus.prometheusSpec.additionalScrapeConfigsSecret | object | `{}` |  |
| prometheus.prometheusSpec.additionalPrometheusSecretsAnnotations | object | `{}` |  |
| prometheus.prometheusSpec.additionalAlertManagerConfigs | list | `[]` |  |
| prometheus.prometheusSpec.additionalAlertManagerConfigsSecret | object | `{}` |  |
| prometheus.prometheusSpec.additionalAlertRelabelConfigs | list | `[]` |  |
| prometheus.prometheusSpec.additionalAlertRelabelConfigsSecret | object | `{}` |  |
| prometheus.prometheusSpec.securityContext.runAsGroup | int | `2000` |  |
| prometheus.prometheusSpec.securityContext.runAsNonRoot | bool | `true` |  |
| prometheus.prometheusSpec.securityContext.runAsUser | int | `1000` |  |
| prometheus.prometheusSpec.securityContext.fsGroup | int | `2000` |  |
| prometheus.prometheusSpec.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| prometheus.prometheusSpec.priorityClassName | string | `""` |  |
| prometheus.prometheusSpec.thanos | object | `{}` |  |
| prometheus.prometheusSpec.containers | list | `[]` |  |
| prometheus.prometheusSpec.initContainers | list | `[]` |  |
| prometheus.prometheusSpec.portName | string | `"http-web"` |  |
| prometheus.prometheusSpec.arbitraryFSAccessThroughSMs | bool | `false` |  |
| prometheus.prometheusSpec.overrideHonorLabels | bool | `false` |  |
| prometheus.prometheusSpec.overrideHonorTimestamps | bool | `false` |  |
| prometheus.prometheusSpec.ignoreNamespaceSelectors | bool | `false` |  |
| prometheus.prometheusSpec.enforcedNamespaceLabel | string | `""` |  |
| prometheus.prometheusSpec.prometheusRulesExcludedFromEnforce | list | `[]` |  |
| prometheus.prometheusSpec.excludedFromEnforcement | list | `[]` |  |
| prometheus.prometheusSpec.queryLogFile | bool | `false` |  |
| prometheus.prometheusSpec.sampleLimit | bool | `false` |  |
| prometheus.prometheusSpec.enforcedKeepDroppedTargets | int | `0` |  |
| prometheus.prometheusSpec.enforcedSampleLimit | bool | `false` |  |
| prometheus.prometheusSpec.enforcedTargetLimit | bool | `false` |  |
| prometheus.prometheusSpec.enforcedLabelLimit | bool | `false` |  |
| prometheus.prometheusSpec.enforcedLabelNameLengthLimit | bool | `false` |  |
| prometheus.prometheusSpec.enforcedLabelValueLengthLimit | bool | `false` |  |
| prometheus.prometheusSpec.allowOverlappingBlocks | bool | `false` |  |
| prometheus.prometheusSpec.nameValidationScheme | string | `""` |  |
| prometheus.prometheusSpec.minReadySeconds | int | `0` |  |
| prometheus.prometheusSpec.hostNetwork | bool | `false` |  |
| prometheus.prometheusSpec.hostAliases | list | `[]` |  |
| prometheus.prometheusSpec.tracingConfig | object | `{}` |  |
| prometheus.prometheusSpec.serviceDiscoveryRole | string | `""` |  |
| prometheus.prometheusSpec.additionalConfig | object | `{}` |  |
| prometheus.prometheusSpec.additionalConfigString | string | `""` |  |
| prometheus.prometheusSpec.maximumStartupDurationSeconds | int | `0` |  |
| prometheus.additionalRulesForClusterRole | list | `[]` |  |
| prometheus.additionalServiceMonitors | list | `[]` |  |
| prometheus.additionalPodMonitors | list | `[]` |  |
| thanosRuler.enabled | bool | `false` |  |
| thanosRuler.annotations | object | `{}` |  |
| thanosRuler.serviceAccount.create | bool | `true` |  |
| thanosRuler.serviceAccount.name | string | `""` |  |
| thanosRuler.serviceAccount.annotations | object | `{}` |  |
| thanosRuler.podDisruptionBudget.enabled | bool | `false` |  |
| thanosRuler.podDisruptionBudget.minAvailable | int | `1` |  |
| thanosRuler.podDisruptionBudget.maxUnavailable | string | `""` |  |
| thanosRuler.ingress.enabled | bool | `false` |  |
| thanosRuler.ingress.annotations | object | `{}` |  |
| thanosRuler.ingress.labels | object | `{}` |  |
| thanosRuler.ingress.hosts | list | `[]` |  |
| thanosRuler.ingress.paths | list | `[]` |  |
| thanosRuler.ingress.tls | list | `[]` |  |
| thanosRuler.route | object | `{"main":{"additionalRules":[],"annotations":{},"apiVersion":"gateway.networking.k8s.io/v1","enabled":false,"filters":[],"hostnames":[],"httpsRedirect":false,"kind":"HTTPRoute","labels":{},"matches":[{"path":{"type":"PathPrefix","value":"/"}}],"parentRefs":[]}}` | BETA: Configure the gateway routes for the chart here. More routes can be added by adding a dictionary key like the 'main' route. Be aware that this is an early beta of this feature, kube-prometheus-stack does not guarantee this works and is subject to change. Being BETA this can/will change in the future without notice, do not use unless you want to take that risk [[ref]](https://gateway-api.sigs.k8s.io/references/spec/#gateway.networking.k8s.io%2fv1alpha2) |
| thanosRuler.route.main.enabled | bool | `false` | Enables or disables the route |
| thanosRuler.route.main.apiVersion | string | `"gateway.networking.k8s.io/v1"` | Set the route apiVersion, e.g. gateway.networking.k8s.io/v1 or gateway.networking.k8s.io/v1alpha2 |
| thanosRuler.route.main.kind | string | `"HTTPRoute"` | Set the route kind Valid options are GRPCRoute, HTTPRoute, TCPRoute, TLSRoute, UDPRoute |
| thanosRuler.route.main.httpsRedirect | bool | `false` | create http route for redirect (https://gateway-api.sigs.k8s.io/guides/http-redirect-rewrite/#http-to-https-redirects) # Take care that you only enable this on the http listener of the gateway to avoid an infinite redirect. # matches, filters and additionalRules will be ignored if this is set to true. Be are |
| thanosRuler.service.annotations | object | `{}` |  |
| thanosRuler.service.labels | object | `{}` |  |
| thanosRuler.service.clusterIP | string | `""` |  |
| thanosRuler.service.ipDualStack.enabled | bool | `false` |  |
| thanosRuler.service.ipDualStack.ipFamilies[0] | string | `"IPv6"` |  |
| thanosRuler.service.ipDualStack.ipFamilies[1] | string | `"IPv4"` |  |
| thanosRuler.service.ipDualStack.ipFamilyPolicy | string | `"PreferDualStack"` |  |
| thanosRuler.service.port | int | `10902` |  |
| thanosRuler.service.targetPort | int | `10902` |  |
| thanosRuler.service.nodePort | int | `30905` |  |
| thanosRuler.service.additionalPorts | list | `[]` |  |
| thanosRuler.service.externalIPs | list | `[]` |  |
| thanosRuler.service.loadBalancerIP | string | `""` |  |
| thanosRuler.service.loadBalancerSourceRanges | list | `[]` |  |
| thanosRuler.service.externalTrafficPolicy | string | `"Cluster"` |  |
| thanosRuler.service.type | string | `"ClusterIP"` |  |
| thanosRuler.serviceMonitor.selfMonitor | bool | `true` |  |
| thanosRuler.serviceMonitor.interval | string | `""` |  |
| thanosRuler.serviceMonitor.additionalLabels | object | `{}` |  |
| thanosRuler.serviceMonitor.sampleLimit | int | `0` |  |
| thanosRuler.serviceMonitor.targetLimit | int | `0` |  |
| thanosRuler.serviceMonitor.labelLimit | int | `0` |  |
| thanosRuler.serviceMonitor.labelNameLengthLimit | int | `0` |  |
| thanosRuler.serviceMonitor.labelValueLengthLimit | int | `0` |  |
| thanosRuler.serviceMonitor.proxyUrl | string | `""` |  |
| thanosRuler.serviceMonitor.scheme | string | `""` |  |
| thanosRuler.serviceMonitor.tlsConfig | object | `{}` |  |
| thanosRuler.serviceMonitor.bearerTokenFile | string | `nil` |  |
| thanosRuler.serviceMonitor.metricRelabelings | list | `[]` |  |
| thanosRuler.serviceMonitor.relabelings | list | `[]` |  |
| thanosRuler.serviceMonitor.additionalEndpoints | list | `[]` |  |
| thanosRuler.thanosRulerSpec.podMetadata | object | `{}` |  |
| thanosRuler.thanosRulerSpec.image.registry | string | `"registry1.dso.mil"` |  |
| thanosRuler.thanosRulerSpec.image.repository | string | `"ironbank/opensource/thanos/thanos"` |  |
| thanosRuler.thanosRulerSpec.image.tag | string | `"v0.37.2"` |  |
| thanosRuler.thanosRulerSpec.image.sha | string | `""` |  |
| thanosRuler.thanosRulerSpec.ruleNamespaceSelector | object | `{}` |  |
| thanosRuler.thanosRulerSpec.ruleSelectorNilUsesHelmValues | bool | `true` |  |
| thanosRuler.thanosRulerSpec.ruleSelector | object | `{}` |  |
| thanosRuler.thanosRulerSpec.logFormat | string | `"logfmt"` |  |
| thanosRuler.thanosRulerSpec.logLevel | string | `"info"` |  |
| thanosRuler.thanosRulerSpec.replicas | int | `1` |  |
| thanosRuler.thanosRulerSpec.retention | string | `"24h"` |  |
| thanosRuler.thanosRulerSpec.evaluationInterval | string | `""` |  |
| thanosRuler.thanosRulerSpec.storage | object | `{}` |  |
| thanosRuler.thanosRulerSpec.alertmanagersConfig.existingSecret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.alertmanagersConfig.secret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.externalPrefix | string | `nil` |  |
| thanosRuler.thanosRulerSpec.externalPrefixNilUsesHelmValues | bool | `true` |  |
| thanosRuler.thanosRulerSpec.routePrefix | string | `"/"` |  |
| thanosRuler.thanosRulerSpec.objectStorageConfig.existingSecret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.objectStorageConfig.secret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.alertDropLabels | list | `[]` |  |
| thanosRuler.thanosRulerSpec.queryEndpoints | list | `[]` |  |
| thanosRuler.thanosRulerSpec.queryConfig.existingSecret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.queryConfig.secret | object | `{}` |  |
| thanosRuler.thanosRulerSpec.labels | object | `{}` |  |
| thanosRuler.thanosRulerSpec.paused | bool | `false` |  |
| thanosRuler.thanosRulerSpec.additionalArgs | list | `[]` |  |
| thanosRuler.thanosRulerSpec.nodeSelector | object | `{}` |  |
| thanosRuler.thanosRulerSpec.resources | object | `{}` |  |
| thanosRuler.thanosRulerSpec.podAntiAffinity | string | `"soft"` |  |
| thanosRuler.thanosRulerSpec.podAntiAffinityTopologyKey | string | `"kubernetes.io/hostname"` |  |
| thanosRuler.thanosRulerSpec.affinity | object | `{}` |  |
| thanosRuler.thanosRulerSpec.tolerations | list | `[]` |  |
| thanosRuler.thanosRulerSpec.topologySpreadConstraints | list | `[]` |  |
| thanosRuler.thanosRulerSpec.securityContext.runAsGroup | int | `2000` |  |
| thanosRuler.thanosRulerSpec.securityContext.runAsNonRoot | bool | `true` |  |
| thanosRuler.thanosRulerSpec.securityContext.runAsUser | int | `1000` |  |
| thanosRuler.thanosRulerSpec.securityContext.fsGroup | int | `2000` |  |
| thanosRuler.thanosRulerSpec.securityContext.seccompProfile.type | string | `"RuntimeDefault"` |  |
| thanosRuler.thanosRulerSpec.listenLocal | bool | `false` |  |
| thanosRuler.thanosRulerSpec.containers | list | `[]` |  |
| thanosRuler.thanosRulerSpec.volumes | list | `[]` |  |
| thanosRuler.thanosRulerSpec.volumeMounts | list | `[]` |  |
| thanosRuler.thanosRulerSpec.initContainers | list | `[]` |  |
| thanosRuler.thanosRulerSpec.priorityClassName | string | `""` |  |
| thanosRuler.thanosRulerSpec.portName | string | `"web"` |  |
| thanosRuler.thanosRulerSpec.web | object | `{}` |  |
| thanosRuler.thanosRulerSpec.additionalConfig | object | `{}` |  |
| thanosRuler.thanosRulerSpec.additionalConfigString | string | `""` |  |
| thanosRuler.extraSecret.annotations | object | `{}` |  |
| thanosRuler.extraSecret.data | object | `{}` |  |
| cleanPrometheusOperatorObjectNames | bool | `false` |  |
| extraManifests | list | `[]` |  |

## Contributing

Please see the [contributing guide](./CONTRIBUTING.md) if you are interested in contributing.

---

_This file is programatically generated using `helm-docs` and some BigBang-specific templates. The `gluon` repository has [instructions for regenerating package READMEs](https://repo1.dso.mil/big-bang/product/packages/gluon/-/blob/master/docs/bb-package-readme.md)._

